# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetBasicAccelerateIpResponseBody(DaraModel):
    def __init__(
        self,
        accelerate_ip_address: str = None,
        accelerate_ip_id: str = None,
        accelerator_id: str = None,
        ip_set_id: str = None,
        request_id: str = None,
        state: str = None,
    ):
        # The accelerated IP address of the basic GA instance.
        self.accelerate_ip_address = accelerate_ip_address
        # The ID of the accelerated IP address.
        self.accelerate_ip_id = accelerate_ip_id
        # The ID of the basic GA instance to which the queried accelerated IP address belongs.
        self.accelerator_id = accelerator_id
        # The ID of the acceleration region of the basic GA instance.
        self.ip_set_id = ip_set_id
        # The request ID.
        self.request_id = request_id
        # The status of the accelerated IP address. Valid values:
        # 
        # *   **active**: The accelerated IP address is available.
        # *   **binding**: The accelerated IP address is being associated.
        # *   **bound**: The accelerated IP address is associated.
        # *   **unbinding**: The accelerated IP address is being disassociated.
        # *   **deleting**: The GA instance is being deleted.
        # 
        # >  If the accelerated IP address is being created, this parameter is not returned.
        self.state = state

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.accelerate_ip_address is not None:
            result['AccelerateIpAddress'] = self.accelerate_ip_address

        if self.accelerate_ip_id is not None:
            result['AccelerateIpId'] = self.accelerate_ip_id

        if self.accelerator_id is not None:
            result['AcceleratorId'] = self.accelerator_id

        if self.ip_set_id is not None:
            result['IpSetId'] = self.ip_set_id

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.state is not None:
            result['State'] = self.state

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AccelerateIpAddress') is not None:
            self.accelerate_ip_address = m.get('AccelerateIpAddress')

        if m.get('AccelerateIpId') is not None:
            self.accelerate_ip_id = m.get('AccelerateIpId')

        if m.get('AcceleratorId') is not None:
            self.accelerator_id = m.get('AcceleratorId')

        if m.get('IpSetId') is not None:
            self.ip_set_id = m.get('IpSetId')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('State') is not None:
            self.state = m.get('State')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_ga20191120 import models as main_models
from darabonba.model import DaraModel

class ListBandwidthackagesResponseBody(DaraModel):
    def __init__(
        self,
        bandwidth_packages: List[main_models.ListBandwidthackagesResponseBodyBandwidthPackages] = None,
        page_number: int = None,
        page_size: int = None,
        request_id: str = None,
        total_count: int = None,
    ):
        # The details of the bandwidth plans.
        self.bandwidth_packages = bandwidth_packages
        # The page number of the returned page.
        self.page_number = page_number
        # The number of entries returned per page.
        self.page_size = page_size
        # The ID of the request.
        self.request_id = request_id
        # The total number of entries returned.
        self.total_count = total_count

    def validate(self):
        if self.bandwidth_packages:
            for v1 in self.bandwidth_packages:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['BandwidthPackages'] = []
        if self.bandwidth_packages is not None:
            for k1 in self.bandwidth_packages:
                result['BandwidthPackages'].append(k1.to_map() if k1 else None)

        if self.page_number is not None:
            result['PageNumber'] = self.page_number

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.bandwidth_packages = []
        if m.get('BandwidthPackages') is not None:
            for k1 in m.get('BandwidthPackages'):
                temp_model = main_models.ListBandwidthackagesResponseBodyBandwidthPackages()
                self.bandwidth_packages.append(temp_model.from_map(k1))

        if m.get('PageNumber') is not None:
            self.page_number = m.get('PageNumber')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        return self

class ListBandwidthackagesResponseBodyBandwidthPackages(DaraModel):
    def __init__(
        self,
        accelerators: List[str] = None,
        bandwidth: int = None,
        bandwidth_package_id: str = None,
        charge_type: str = None,
        create_time: str = None,
        description: str = None,
        expired_time: str = None,
        name: str = None,
        region_id: str = None,
        resource_group_id: str = None,
        state: str = None,
        tags: List[main_models.ListBandwidthackagesResponseBodyBandwidthPackagesTags] = None,
    ):
        # The IDs of the GA instances that are associated with the bandwidth plans.
        self.accelerators = accelerators
        # The bandwidth of the bandwidth plan. Unit: Mbit/s.
        self.bandwidth = bandwidth
        # The ID of the bandwidth plan.
        self.bandwidth_package_id = bandwidth_package_id
        # The billing method of the bandwidth plan. Valid values:
        # 
        # *   **PREPAY**: subscription. This is the default value.
        # *   **POSTPAY**: pay-as-you-go.
        self.charge_type = charge_type
        # The time when the bandwidth plan was created.
        self.create_time = create_time
        # The description of the bandwidth plan.
        self.description = description
        # The expiration time of the bandwidth plan.
        self.expired_time = expired_time
        # The name of the GA instance.
        self.name = name
        # The request ID.
        self.region_id = region_id
        # The ID of the resource group.
        self.resource_group_id = resource_group_id
        # The status of the bandwidth plan. Valid values:
        # 
        # *   **init:** The bandwidth plan is being initialized.
        # *   **active:** The bandwidth plan is available.
        # *   **binded:** The bandwidth plan is associated with a GA instance.
        # *   **binding:** The bandwidth plan is being associated with a GA instance.
        # *   **unbinding:** The bandwidth plan is being disassociated from a GA instance.
        # *   **updating:** The bandwidth plan is being updated.
        # *   **finacialLocked:** The bandwidth plan is locked due to overdue payments.
        # *   **locked:** The bandwidth plan is locked.
        self.state = state
        # The tag of the bandwidth plan.
        self.tags = tags

    def validate(self):
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.accelerators is not None:
            result['Accelerators'] = self.accelerators

        if self.bandwidth is not None:
            result['Bandwidth'] = self.bandwidth

        if self.bandwidth_package_id is not None:
            result['BandwidthPackageId'] = self.bandwidth_package_id

        if self.charge_type is not None:
            result['ChargeType'] = self.charge_type

        if self.create_time is not None:
            result['CreateTime'] = self.create_time

        if self.description is not None:
            result['Description'] = self.description

        if self.expired_time is not None:
            result['ExpiredTime'] = self.expired_time

        if self.name is not None:
            result['Name'] = self.name

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        if self.resource_group_id is not None:
            result['ResourceGroupId'] = self.resource_group_id

        if self.state is not None:
            result['State'] = self.state

        result['Tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['Tags'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Accelerators') is not None:
            self.accelerators = m.get('Accelerators')

        if m.get('Bandwidth') is not None:
            self.bandwidth = m.get('Bandwidth')

        if m.get('BandwidthPackageId') is not None:
            self.bandwidth_package_id = m.get('BandwidthPackageId')

        if m.get('ChargeType') is not None:
            self.charge_type = m.get('ChargeType')

        if m.get('CreateTime') is not None:
            self.create_time = m.get('CreateTime')

        if m.get('Description') is not None:
            self.description = m.get('Description')

        if m.get('ExpiredTime') is not None:
            self.expired_time = m.get('ExpiredTime')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        if m.get('ResourceGroupId') is not None:
            self.resource_group_id = m.get('ResourceGroupId')

        if m.get('State') is not None:
            self.state = m.get('State')

        self.tags = []
        if m.get('Tags') is not None:
            for k1 in m.get('Tags'):
                temp_model = main_models.ListBandwidthackagesResponseBodyBandwidthPackagesTags()
                self.tags.append(temp_model.from_map(k1))

        return self

class ListBandwidthackagesResponseBodyBandwidthPackagesTags(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        # The tag key of the bandwidth plan.
        self.key = key
        # The tag value of the bandwidth plan.
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_ga20191120 import models as main_models
from darabonba.model import DaraModel

class UpdateCustomRoutingEndpointGroupDestinationsRequest(DaraModel):
    def __init__(
        self,
        client_token: str = None,
        destination_configurations: List[main_models.UpdateCustomRoutingEndpointGroupDestinationsRequestDestinationConfigurations] = None,
        dry_run: bool = None,
        endpoint_group_id: str = None,
        region_id: str = None,
    ):
        # The client token that is used to ensure the idempotence of the request.
        # 
        # You can use the client to generate the value, but you must ensure that it is unique among all requests. The client token can contain only ASCII characters.
        # 
        # > If you do not specify this parameter, the system automatically uses the value of **RequestId** as the value of **ClientToken**. The value of **RequestId** for each API request may be different.
        self.client_token = client_token
        # The mapping configurations of endpoint group.
        # 
        # You must specify the backend service port range and protocol of the endpoint group. The specified information is used to map the port range of the associated listener.
        # 
        # You can specify at most 20 mapping configurations, which include port ranges and protocol types.
        # 
        # This parameter is required.
        self.destination_configurations = destination_configurations
        # Specifies whether to perform a dry run. Valid values:
        # 
        # *   **true**: performs a dry run. The system checks the required parameters, request syntax, and limits. If the request fails the dry run, an error message is returned. If the request passes the dry run, the `DryRunOperation` error code is returned.
        # *   **false**: performs a dry run and sends the request. If the request passes the dry run, a 2xx HTTP status code is returned and the operation is performed.
        self.dry_run = dry_run
        # The ID of the endpoint group.
        # 
        # This parameter is required.
        self.endpoint_group_id = endpoint_group_id
        # The ID of the region where the GA instance is deployed. Set the value to **cn-hangzhou**.
        # 
        # This parameter is required.
        self.region_id = region_id

    def validate(self):
        if self.destination_configurations:
            for v1 in self.destination_configurations:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.client_token is not None:
            result['ClientToken'] = self.client_token

        result['DestinationConfigurations'] = []
        if self.destination_configurations is not None:
            for k1 in self.destination_configurations:
                result['DestinationConfigurations'].append(k1.to_map() if k1 else None)

        if self.dry_run is not None:
            result['DryRun'] = self.dry_run

        if self.endpoint_group_id is not None:
            result['EndpointGroupId'] = self.endpoint_group_id

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ClientToken') is not None:
            self.client_token = m.get('ClientToken')

        self.destination_configurations = []
        if m.get('DestinationConfigurations') is not None:
            for k1 in m.get('DestinationConfigurations'):
                temp_model = main_models.UpdateCustomRoutingEndpointGroupDestinationsRequestDestinationConfigurations()
                self.destination_configurations.append(temp_model.from_map(k1))

        if m.get('DryRun') is not None:
            self.dry_run = m.get('DryRun')

        if m.get('EndpointGroupId') is not None:
            self.endpoint_group_id = m.get('EndpointGroupId')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        return self

class UpdateCustomRoutingEndpointGroupDestinationsRequestDestinationConfigurations(DaraModel):
    def __init__(
        self,
        destination_id: str = None,
        from_port: int = None,
        protocols: List[str] = None,
        to_port: int = None,
    ):
        # The ID of the mapping configuration of the endpoint group.
        # 
        # This parameter is required.
        self.destination_id = destination_id
        # The start port of the backend service port range of the endpoint group.
        # 
        # Valid values: **1** to **65499**. The **FromPort** value must be smaller than or equal to the **ToPort** value.
        # 
        # You can specify up to 20 start ports in each request.
        self.from_port = from_port
        # The backend service protocol of the endpoint group. Valid values:
        # 
        # *   **tcp**: TCP
        # *   **udp**: UDP
        # *   **tcp,udp**: TCP and UDP
        # 
        # You can specify up to four backend service protocols in each configuration.
        self.protocols = protocols
        # The end port of the backend service port range of the endpoint group.
        # 
        # Valid values: **1** to **65499**. The **FromPort** value must be smaller than or equal to the **ToPort** value.
        # 
        # You can specify up to 20 end ports in each request.
        self.to_port = to_port

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.destination_id is not None:
            result['DestinationId'] = self.destination_id

        if self.from_port is not None:
            result['FromPort'] = self.from_port

        if self.protocols is not None:
            result['Protocols'] = self.protocols

        if self.to_port is not None:
            result['ToPort'] = self.to_port

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DestinationId') is not None:
            self.destination_id = m.get('DestinationId')

        if m.get('FromPort') is not None:
            self.from_port = m.get('FromPort')

        if m.get('Protocols') is not None:
            self.protocols = m.get('Protocols')

        if m.get('ToPort') is not None:
            self.to_port = m.get('ToPort')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ChangeResourceGroupRequest(DaraModel):
    def __init__(
        self,
        client_token: str = None,
        new_resource_group_id: str = None,
        region_id: str = None,
        resource_id: str = None,
        resource_type: str = None,
    ):
        # The client token that is used to ensure the idempotence of the request.
        # 
        # You can use the client to generate the token, but you must make sure that the token is unique among different requests. The **client token** can contain only ASCII characters.
        # 
        # >  If you do not specify this parameter, the system automatically uses the value of **RequestId** as the value of **ClientToken**. The **request ID** may be different for each request.
        self.client_token = client_token
        # The ID of the new resource group.
        # 
        # This parameter is required.
        self.new_resource_group_id = new_resource_group_id
        # The ID of the region where the GA instance is deployed. Set the value to **cn-hangzhou**.
        # 
        # This parameter is required.
        self.region_id = region_id
        # The ID of the GA resource.
        # 
        # *   If you set **ResourceType** to **accelerator**, set the value of ResourceId to the ID of a standard GA instance.
        # *   If you set **ResourceType** to **basicaccelerator**, set the value of ResourceId to the ID of a basic GA instance.
        # *   If you set **ResourceType** to **bandwidthpackage**, set the value of ResourceId to the ID of a bandwidth plan.
        # *   If you set **ResourceType** to **acl**, set the value of ResourceId to the ID of an access control list (ACL).
        # 
        # This parameter is required.
        self.resource_id = resource_id
        # The type of the GA resource. Valid values:
        # 
        # *   **accelerator:** a standard GA instance.
        # *   **basicaccelerator:** a basic GA instance.
        # *   **bandwidthpackage:** a bandwidth plan.
        # *   **acl:** an ACL.
        # 
        # This parameter is required.
        self.resource_type = resource_type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.client_token is not None:
            result['ClientToken'] = self.client_token

        if self.new_resource_group_id is not None:
            result['NewResourceGroupId'] = self.new_resource_group_id

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        if self.resource_id is not None:
            result['ResourceId'] = self.resource_id

        if self.resource_type is not None:
            result['ResourceType'] = self.resource_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ClientToken') is not None:
            self.client_token = m.get('ClientToken')

        if m.get('NewResourceGroupId') is not None:
            self.new_resource_group_id = m.get('NewResourceGroupId')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        if m.get('ResourceId') is not None:
            self.resource_id = m.get('ResourceId')

        if m.get('ResourceType') is not None:
            self.resource_type = m.get('ResourceType')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class UpdateCustomRoutingEndpointTrafficPoliciesResponseBody(DaraModel):
    def __init__(
        self,
        policy_ids: List[str] = None,
        request_id: str = None,
    ):
        # The IDs of the traffic destinations.
        self.policy_ids = policy_ids
        # The request ID.
        self.request_id = request_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.policy_ids is not None:
            result['PolicyIds'] = self.policy_ids

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('PolicyIds') is not None:
            self.policy_ids = m.get('PolicyIds')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from ._add_entries_to_acl_request import AddEntriesToAclRequest
from ._add_entries_to_acl_response_body import AddEntriesToAclResponseBody
from ._add_entries_to_acl_response import AddEntriesToAclResponse
from ._associate_acls_with_listener_request import AssociateAclsWithListenerRequest
from ._associate_acls_with_listener_response_body import AssociateAclsWithListenerResponseBody
from ._associate_acls_with_listener_response import AssociateAclsWithListenerResponse
from ._associate_additional_certificates_with_listener_request import AssociateAdditionalCertificatesWithListenerRequest
from ._associate_additional_certificates_with_listener_response_body import AssociateAdditionalCertificatesWithListenerResponseBody
from ._associate_additional_certificates_with_listener_response import AssociateAdditionalCertificatesWithListenerResponse
from ._associate_resources_request import AssociateResourcesRequest
from ._associate_resources_response_body import AssociateResourcesResponseBody
from ._associate_resources_response import AssociateResourcesResponse
from ._attach_ddos_to_accelerator_request import AttachDdosToAcceleratorRequest
from ._attach_ddos_to_accelerator_response_body import AttachDdosToAcceleratorResponseBody
from ._attach_ddos_to_accelerator_response import AttachDdosToAcceleratorResponse
from ._attach_log_store_to_endpoint_group_request import AttachLogStoreToEndpointGroupRequest
from ._attach_log_store_to_endpoint_group_response_body import AttachLogStoreToEndpointGroupResponseBody
from ._attach_log_store_to_endpoint_group_response import AttachLogStoreToEndpointGroupResponse
from ._bandwidth_package_add_accelerator_request import BandwidthPackageAddAcceleratorRequest
from ._bandwidth_package_add_accelerator_response_body import BandwidthPackageAddAcceleratorResponseBody
from ._bandwidth_package_add_accelerator_response import BandwidthPackageAddAcceleratorResponse
from ._bandwidth_package_remove_accelerator_request import BandwidthPackageRemoveAcceleratorRequest
from ._bandwidth_package_remove_accelerator_response_body import BandwidthPackageRemoveAcceleratorResponseBody
from ._bandwidth_package_remove_accelerator_response import BandwidthPackageRemoveAcceleratorResponse
from ._change_resource_group_request import ChangeResourceGroupRequest
from ._change_resource_group_response_body import ChangeResourceGroupResponseBody
from ._change_resource_group_response import ChangeResourceGroupResponse
from ._config_endpoint_probe_request import ConfigEndpointProbeRequest
from ._config_endpoint_probe_response_body import ConfigEndpointProbeResponseBody
from ._config_endpoint_probe_response import ConfigEndpointProbeResponse
from ._create_accelerator_request import CreateAcceleratorRequest
from ._create_accelerator_response_body import CreateAcceleratorResponseBody
from ._create_accelerator_response import CreateAcceleratorResponse
from ._create_acl_request import CreateAclRequest
from ._create_acl_response_body import CreateAclResponseBody
from ._create_acl_response import CreateAclResponse
from ._create_application_monitor_request import CreateApplicationMonitorRequest
from ._create_application_monitor_response_body import CreateApplicationMonitorResponseBody
from ._create_application_monitor_response import CreateApplicationMonitorResponse
from ._create_bandwidth_package_request import CreateBandwidthPackageRequest
from ._create_bandwidth_package_response_body import CreateBandwidthPackageResponseBody
from ._create_bandwidth_package_response import CreateBandwidthPackageResponse
from ._create_basic_accelerate_ip_request import CreateBasicAccelerateIpRequest
from ._create_basic_accelerate_ip_response_body import CreateBasicAccelerateIpResponseBody
from ._create_basic_accelerate_ip_response import CreateBasicAccelerateIpResponse
from ._create_basic_accelerate_ip_endpoint_relation_request import CreateBasicAccelerateIpEndpointRelationRequest
from ._create_basic_accelerate_ip_endpoint_relation_response_body import CreateBasicAccelerateIpEndpointRelationResponseBody
from ._create_basic_accelerate_ip_endpoint_relation_response import CreateBasicAccelerateIpEndpointRelationResponse
from ._create_basic_accelerate_ip_endpoint_relations_request import CreateBasicAccelerateIpEndpointRelationsRequest
from ._create_basic_accelerate_ip_endpoint_relations_response_body import CreateBasicAccelerateIpEndpointRelationsResponseBody
from ._create_basic_accelerate_ip_endpoint_relations_response import CreateBasicAccelerateIpEndpointRelationsResponse
from ._create_basic_accelerator_request import CreateBasicAcceleratorRequest
from ._create_basic_accelerator_response_body import CreateBasicAcceleratorResponseBody
from ._create_basic_accelerator_response import CreateBasicAcceleratorResponse
from ._create_basic_endpoint_request import CreateBasicEndpointRequest
from ._create_basic_endpoint_response_body import CreateBasicEndpointResponseBody
from ._create_basic_endpoint_response import CreateBasicEndpointResponse
from ._create_basic_endpoint_group_request import CreateBasicEndpointGroupRequest
from ._create_basic_endpoint_group_response_body import CreateBasicEndpointGroupResponseBody
from ._create_basic_endpoint_group_response import CreateBasicEndpointGroupResponse
from ._create_basic_endpoints_request import CreateBasicEndpointsRequest
from ._create_basic_endpoints_response_body import CreateBasicEndpointsResponseBody
from ._create_basic_endpoints_response import CreateBasicEndpointsResponse
from ._create_basic_ip_set_request import CreateBasicIpSetRequest
from ._create_basic_ip_set_response_body import CreateBasicIpSetResponseBody
from ._create_basic_ip_set_response import CreateBasicIpSetResponse
from ._create_custom_routing_endpoint_group_destinations_request import CreateCustomRoutingEndpointGroupDestinationsRequest
from ._create_custom_routing_endpoint_group_destinations_response_body import CreateCustomRoutingEndpointGroupDestinationsResponseBody
from ._create_custom_routing_endpoint_group_destinations_response import CreateCustomRoutingEndpointGroupDestinationsResponse
from ._create_custom_routing_endpoint_groups_request import CreateCustomRoutingEndpointGroupsRequest
from ._create_custom_routing_endpoint_groups_response_body import CreateCustomRoutingEndpointGroupsResponseBody
from ._create_custom_routing_endpoint_groups_response import CreateCustomRoutingEndpointGroupsResponse
from ._create_custom_routing_endpoint_traffic_policies_request import CreateCustomRoutingEndpointTrafficPoliciesRequest
from ._create_custom_routing_endpoint_traffic_policies_response_body import CreateCustomRoutingEndpointTrafficPoliciesResponseBody
from ._create_custom_routing_endpoint_traffic_policies_response import CreateCustomRoutingEndpointTrafficPoliciesResponse
from ._create_custom_routing_endpoints_request import CreateCustomRoutingEndpointsRequest
from ._create_custom_routing_endpoints_response_body import CreateCustomRoutingEndpointsResponseBody
from ._create_custom_routing_endpoints_response import CreateCustomRoutingEndpointsResponse
from ._create_domain_request import CreateDomainRequest
from ._create_domain_response_body import CreateDomainResponseBody
from ._create_domain_response import CreateDomainResponse
from ._create_endpoint_group_request import CreateEndpointGroupRequest
from ._create_endpoint_group_response_body import CreateEndpointGroupResponseBody
from ._create_endpoint_group_response import CreateEndpointGroupResponse
from ._create_endpoint_groups_request import CreateEndpointGroupsRequest
from ._create_endpoint_groups_response_body import CreateEndpointGroupsResponseBody
from ._create_endpoint_groups_response import CreateEndpointGroupsResponse
from ._create_forwarding_rules_request import CreateForwardingRulesRequest
from ._create_forwarding_rules_response_body import CreateForwardingRulesResponseBody
from ._create_forwarding_rules_response import CreateForwardingRulesResponse
from ._create_ip_sets_request import CreateIpSetsRequest
from ._create_ip_sets_response_body import CreateIpSetsResponseBody
from ._create_ip_sets_response import CreateIpSetsResponse
from ._create_listener_request import CreateListenerRequest
from ._create_listener_response_body import CreateListenerResponseBody
from ._create_listener_response import CreateListenerResponse
from ._create_spare_ips_request import CreateSpareIpsRequest
from ._create_spare_ips_response_body import CreateSpareIpsResponseBody
from ._create_spare_ips_response import CreateSpareIpsResponse
from ._delete_accelerator_request import DeleteAcceleratorRequest
from ._delete_accelerator_response_body import DeleteAcceleratorResponseBody
from ._delete_accelerator_response import DeleteAcceleratorResponse
from ._delete_acl_request import DeleteAclRequest
from ._delete_acl_response_body import DeleteAclResponseBody
from ._delete_acl_response import DeleteAclResponse
from ._delete_application_monitor_request import DeleteApplicationMonitorRequest
from ._delete_application_monitor_response_body import DeleteApplicationMonitorResponseBody
from ._delete_application_monitor_response import DeleteApplicationMonitorResponse
from ._delete_bandwidth_package_request import DeleteBandwidthPackageRequest
from ._delete_bandwidth_package_response_body import DeleteBandwidthPackageResponseBody
from ._delete_bandwidth_package_response import DeleteBandwidthPackageResponse
from ._delete_basic_accelerate_ip_request import DeleteBasicAccelerateIpRequest
from ._delete_basic_accelerate_ip_response_body import DeleteBasicAccelerateIpResponseBody
from ._delete_basic_accelerate_ip_response import DeleteBasicAccelerateIpResponse
from ._delete_basic_accelerate_ip_endpoint_relation_request import DeleteBasicAccelerateIpEndpointRelationRequest
from ._delete_basic_accelerate_ip_endpoint_relation_response_body import DeleteBasicAccelerateIpEndpointRelationResponseBody
from ._delete_basic_accelerate_ip_endpoint_relation_response import DeleteBasicAccelerateIpEndpointRelationResponse
from ._delete_basic_accelerator_request import DeleteBasicAcceleratorRequest
from ._delete_basic_accelerator_response_body import DeleteBasicAcceleratorResponseBody
from ._delete_basic_accelerator_response import DeleteBasicAcceleratorResponse
from ._delete_basic_endpoint_request import DeleteBasicEndpointRequest
from ._delete_basic_endpoint_response_body import DeleteBasicEndpointResponseBody
from ._delete_basic_endpoint_response import DeleteBasicEndpointResponse
from ._delete_basic_endpoint_group_request import DeleteBasicEndpointGroupRequest
from ._delete_basic_endpoint_group_response_body import DeleteBasicEndpointGroupResponseBody
from ._delete_basic_endpoint_group_response import DeleteBasicEndpointGroupResponse
from ._delete_basic_ip_set_request import DeleteBasicIpSetRequest
from ._delete_basic_ip_set_response_body import DeleteBasicIpSetResponseBody
from ._delete_basic_ip_set_response import DeleteBasicIpSetResponse
from ._delete_custom_routing_endpoint_group_destinations_request import DeleteCustomRoutingEndpointGroupDestinationsRequest
from ._delete_custom_routing_endpoint_group_destinations_response_body import DeleteCustomRoutingEndpointGroupDestinationsResponseBody
from ._delete_custom_routing_endpoint_group_destinations_response import DeleteCustomRoutingEndpointGroupDestinationsResponse
from ._delete_custom_routing_endpoint_groups_request import DeleteCustomRoutingEndpointGroupsRequest
from ._delete_custom_routing_endpoint_groups_response_body import DeleteCustomRoutingEndpointGroupsResponseBody
from ._delete_custom_routing_endpoint_groups_response import DeleteCustomRoutingEndpointGroupsResponse
from ._delete_custom_routing_endpoint_traffic_policies_request import DeleteCustomRoutingEndpointTrafficPoliciesRequest
from ._delete_custom_routing_endpoint_traffic_policies_response_body import DeleteCustomRoutingEndpointTrafficPoliciesResponseBody
from ._delete_custom_routing_endpoint_traffic_policies_response import DeleteCustomRoutingEndpointTrafficPoliciesResponse
from ._delete_custom_routing_endpoints_request import DeleteCustomRoutingEndpointsRequest
from ._delete_custom_routing_endpoints_response_body import DeleteCustomRoutingEndpointsResponseBody
from ._delete_custom_routing_endpoints_response import DeleteCustomRoutingEndpointsResponse
from ._delete_domain_accelerator_relation_request import DeleteDomainAcceleratorRelationRequest
from ._delete_domain_accelerator_relation_response_body import DeleteDomainAcceleratorRelationResponseBody
from ._delete_domain_accelerator_relation_response import DeleteDomainAcceleratorRelationResponse
from ._delete_endpoint_group_request import DeleteEndpointGroupRequest
from ._delete_endpoint_group_response_body import DeleteEndpointGroupResponseBody
from ._delete_endpoint_group_response import DeleteEndpointGroupResponse
from ._delete_endpoint_groups_request import DeleteEndpointGroupsRequest
from ._delete_endpoint_groups_response_body import DeleteEndpointGroupsResponseBody
from ._delete_endpoint_groups_response import DeleteEndpointGroupsResponse
from ._delete_forwarding_rules_request import DeleteForwardingRulesRequest
from ._delete_forwarding_rules_response_body import DeleteForwardingRulesResponseBody
from ._delete_forwarding_rules_response import DeleteForwardingRulesResponse
from ._delete_ip_set_request import DeleteIpSetRequest
from ._delete_ip_set_response_body import DeleteIpSetResponseBody
from ._delete_ip_set_response import DeleteIpSetResponse
from ._delete_ip_sets_request import DeleteIpSetsRequest
from ._delete_ip_sets_response_body import DeleteIpSetsResponseBody
from ._delete_ip_sets_response import DeleteIpSetsResponse
from ._delete_listener_request import DeleteListenerRequest
from ._delete_listener_response_body import DeleteListenerResponseBody
from ._delete_listener_response import DeleteListenerResponse
from ._delete_spare_ips_request import DeleteSpareIpsRequest
from ._delete_spare_ips_response_body import DeleteSpareIpsResponseBody
from ._delete_spare_ips_response import DeleteSpareIpsResponse
from ._describe_accelerator_request import DescribeAcceleratorRequest
from ._describe_accelerator_response_body import DescribeAcceleratorResponseBody
from ._describe_accelerator_response import DescribeAcceleratorResponse
from ._describe_accelerator_auto_renew_attribute_request import DescribeAcceleratorAutoRenewAttributeRequest
from ._describe_accelerator_auto_renew_attribute_response_body import DescribeAcceleratorAutoRenewAttributeResponseBody
from ._describe_accelerator_auto_renew_attribute_response import DescribeAcceleratorAutoRenewAttributeResponse
from ._describe_accelerator_service_status_request import DescribeAcceleratorServiceStatusRequest
from ._describe_accelerator_service_status_response_body import DescribeAcceleratorServiceStatusResponseBody
from ._describe_accelerator_service_status_response import DescribeAcceleratorServiceStatusResponse
from ._describe_application_monitor_request import DescribeApplicationMonitorRequest
from ._describe_application_monitor_response_body import DescribeApplicationMonitorResponseBody
from ._describe_application_monitor_response import DescribeApplicationMonitorResponse
from ._describe_bandwidth_package_request import DescribeBandwidthPackageRequest
from ._describe_bandwidth_package_response_body import DescribeBandwidthPackageResponseBody
from ._describe_bandwidth_package_response import DescribeBandwidthPackageResponse
from ._describe_bandwidth_package_auto_renew_attribute_request import DescribeBandwidthPackageAutoRenewAttributeRequest
from ._describe_bandwidth_package_auto_renew_attribute_response_body import DescribeBandwidthPackageAutoRenewAttributeResponseBody
from ._describe_bandwidth_package_auto_renew_attribute_response import DescribeBandwidthPackageAutoRenewAttributeResponse
from ._describe_commodity_request import DescribeCommodityRequest
from ._describe_commodity_response_body import DescribeCommodityResponseBody
from ._describe_commodity_response import DescribeCommodityResponse
from ._describe_commodity_price_request import DescribeCommodityPriceRequest
from ._describe_commodity_price_response_body import DescribeCommodityPriceResponseBody
from ._describe_commodity_price_response import DescribeCommodityPriceResponse
from ._describe_custom_routing_end_point_traffic_policy_request import DescribeCustomRoutingEndPointTrafficPolicyRequest
from ._describe_custom_routing_end_point_traffic_policy_response_body import DescribeCustomRoutingEndPointTrafficPolicyResponseBody
from ._describe_custom_routing_end_point_traffic_policy_response import DescribeCustomRoutingEndPointTrafficPolicyResponse
from ._describe_custom_routing_endpoint_request import DescribeCustomRoutingEndpointRequest
from ._describe_custom_routing_endpoint_response_body import DescribeCustomRoutingEndpointResponseBody
from ._describe_custom_routing_endpoint_response import DescribeCustomRoutingEndpointResponse
from ._describe_custom_routing_endpoint_group_request import DescribeCustomRoutingEndpointGroupRequest
from ._describe_custom_routing_endpoint_group_response_body import DescribeCustomRoutingEndpointGroupResponseBody
from ._describe_custom_routing_endpoint_group_response import DescribeCustomRoutingEndpointGroupResponse
from ._describe_custom_routing_endpoint_group_destinations_request import DescribeCustomRoutingEndpointGroupDestinationsRequest
from ._describe_custom_routing_endpoint_group_destinations_response_body import DescribeCustomRoutingEndpointGroupDestinationsResponseBody
from ._describe_custom_routing_endpoint_group_destinations_response import DescribeCustomRoutingEndpointGroupDestinationsResponse
from ._describe_endpoint_group_request import DescribeEndpointGroupRequest
from ._describe_endpoint_group_response_body import DescribeEndpointGroupResponseBody
from ._describe_endpoint_group_response import DescribeEndpointGroupResponse
from ._describe_ip_set_request import DescribeIpSetRequest
from ._describe_ip_set_response_body import DescribeIpSetResponseBody
from ._describe_ip_set_response import DescribeIpSetResponse
from ._describe_listener_request import DescribeListenerRequest
from ._describe_listener_response_body import DescribeListenerResponseBody
from ._describe_listener_response import DescribeListenerResponse
from ._describe_log_store_of_endpoint_group_request import DescribeLogStoreOfEndpointGroupRequest
from ._describe_log_store_of_endpoint_group_response_body import DescribeLogStoreOfEndpointGroupResponseBody
from ._describe_log_store_of_endpoint_group_response import DescribeLogStoreOfEndpointGroupResponse
from ._describe_regions_request import DescribeRegionsRequest
from ._describe_regions_response_body import DescribeRegionsResponseBody
from ._describe_regions_response import DescribeRegionsResponse
from ._detach_ddos_from_accelerator_request import DetachDdosFromAcceleratorRequest
from ._detach_ddos_from_accelerator_response_body import DetachDdosFromAcceleratorResponseBody
from ._detach_ddos_from_accelerator_response import DetachDdosFromAcceleratorResponse
from ._detach_log_store_from_endpoint_group_request import DetachLogStoreFromEndpointGroupRequest
from ._detach_log_store_from_endpoint_group_response_body import DetachLogStoreFromEndpointGroupResponseBody
from ._detach_log_store_from_endpoint_group_response import DetachLogStoreFromEndpointGroupResponse
from ._detect_application_monitor_request import DetectApplicationMonitorRequest
from ._detect_application_monitor_response_body import DetectApplicationMonitorResponseBody
from ._detect_application_monitor_response import DetectApplicationMonitorResponse
from ._disable_application_monitor_request import DisableApplicationMonitorRequest
from ._disable_application_monitor_response_body import DisableApplicationMonitorResponseBody
from ._disable_application_monitor_response import DisableApplicationMonitorResponse
from ._disassociate_resources_request import DisassociateResourcesRequest
from ._disassociate_resources_response_body import DisassociateResourcesResponseBody
from ._disassociate_resources_response import DisassociateResourcesResponse
from ._dissociate_acls_from_listener_request import DissociateAclsFromListenerRequest
from ._dissociate_acls_from_listener_response_body import DissociateAclsFromListenerResponseBody
from ._dissociate_acls_from_listener_response import DissociateAclsFromListenerResponse
from ._dissociate_additional_certificates_from_listener_request import DissociateAdditionalCertificatesFromListenerRequest
from ._dissociate_additional_certificates_from_listener_response_body import DissociateAdditionalCertificatesFromListenerResponseBody
from ._dissociate_additional_certificates_from_listener_response import DissociateAdditionalCertificatesFromListenerResponse
from ._enable_application_monitor_request import EnableApplicationMonitorRequest
from ._enable_application_monitor_response_body import EnableApplicationMonitorResponseBody
from ._enable_application_monitor_response import EnableApplicationMonitorResponse
from ._get_acl_request import GetAclRequest
from ._get_acl_response_body import GetAclResponseBody
from ._get_acl_response import GetAclResponse
from ._get_basic_accelerate_ip_request import GetBasicAccelerateIpRequest
from ._get_basic_accelerate_ip_response_body import GetBasicAccelerateIpResponseBody
from ._get_basic_accelerate_ip_response import GetBasicAccelerateIpResponse
from ._get_basic_accelerate_ip_endpoint_relation_request import GetBasicAccelerateIpEndpointRelationRequest
from ._get_basic_accelerate_ip_endpoint_relation_response_body import GetBasicAccelerateIpEndpointRelationResponseBody
from ._get_basic_accelerate_ip_endpoint_relation_response import GetBasicAccelerateIpEndpointRelationResponse
from ._get_basic_accelerate_ip_idle_count_request import GetBasicAccelerateIpIdleCountRequest
from ._get_basic_accelerate_ip_idle_count_response_body import GetBasicAccelerateIpIdleCountResponseBody
from ._get_basic_accelerate_ip_idle_count_response import GetBasicAccelerateIpIdleCountResponse
from ._get_basic_accelerator_request import GetBasicAcceleratorRequest
from ._get_basic_accelerator_response_body import GetBasicAcceleratorResponseBody
from ._get_basic_accelerator_response import GetBasicAcceleratorResponse
from ._get_basic_endpoint_request import GetBasicEndpointRequest
from ._get_basic_endpoint_response_body import GetBasicEndpointResponseBody
from ._get_basic_endpoint_response import GetBasicEndpointResponse
from ._get_basic_endpoint_group_request import GetBasicEndpointGroupRequest
from ._get_basic_endpoint_group_response_body import GetBasicEndpointGroupResponseBody
from ._get_basic_endpoint_group_response import GetBasicEndpointGroupResponse
from ._get_basic_ip_set_request import GetBasicIpSetRequest
from ._get_basic_ip_set_response_body import GetBasicIpSetResponseBody
from ._get_basic_ip_set_response import GetBasicIpSetResponse
from ._get_global_accelerator_resources_request import GetGlobalAcceleratorResourcesRequest
from ._get_global_accelerator_resources_response_body import GetGlobalAcceleratorResourcesResponseBody
from ._get_global_accelerator_resources_response import GetGlobalAcceleratorResourcesResponse
from ._get_health_status_request import GetHealthStatusRequest
from ._get_health_status_response_body import GetHealthStatusResponseBody
from ._get_health_status_response import GetHealthStatusResponse
from ._get_invalid_domain_count_request import GetInvalidDomainCountRequest
from ._get_invalid_domain_count_response_body import GetInvalidDomainCountResponseBody
from ._get_invalid_domain_count_response import GetInvalidDomainCountResponse
from ._get_ipsets_bandwidth_limit_request import GetIpsetsBandwidthLimitRequest
from ._get_ipsets_bandwidth_limit_response_body import GetIpsetsBandwidthLimitResponseBody
from ._get_ipsets_bandwidth_limit_response import GetIpsetsBandwidthLimitResponse
from ._get_spare_ip_request import GetSpareIpRequest
from ._get_spare_ip_response_body import GetSpareIpResponseBody
from ._get_spare_ip_response import GetSpareIpResponse
from ._list_accelerate_areas_request import ListAccelerateAreasRequest
from ._list_accelerate_areas_response_body import ListAccelerateAreasResponseBody
from ._list_accelerate_areas_response import ListAccelerateAreasResponse
from ._list_accelerators_request import ListAcceleratorsRequest
from ._list_accelerators_response_body import ListAcceleratorsResponseBody
from ._list_accelerators_response import ListAcceleratorsResponse
from ._list_acls_request import ListAclsRequest
from ._list_acls_response_body import ListAclsResponseBody
from ._list_acls_response import ListAclsResponse
from ._list_application_monitor_request import ListApplicationMonitorRequest
from ._list_application_monitor_response_body import ListApplicationMonitorResponseBody
from ._list_application_monitor_response import ListApplicationMonitorResponse
from ._list_application_monitor_detect_result_request import ListApplicationMonitorDetectResultRequest
from ._list_application_monitor_detect_result_response_body import ListApplicationMonitorDetectResultResponseBody
from ._list_application_monitor_detect_result_response import ListApplicationMonitorDetectResultResponse
from ._list_available_accelerate_areas_request import ListAvailableAccelerateAreasRequest
from ._list_available_accelerate_areas_response_body import ListAvailableAccelerateAreasResponseBody
from ._list_available_accelerate_areas_response import ListAvailableAccelerateAreasResponse
from ._list_available_busi_regions_request import ListAvailableBusiRegionsRequest
from ._list_available_busi_regions_response_body import ListAvailableBusiRegionsResponseBody
from ._list_available_busi_regions_response import ListAvailableBusiRegionsResponse
from ._list_bandwidth_packages_request import ListBandwidthPackagesRequest
from ._list_bandwidth_packages_response_body import ListBandwidthPackagesResponseBody
from ._list_bandwidth_packages_response import ListBandwidthPackagesResponse
from ._list_bandwidthackages_request import ListBandwidthackagesRequest
from ._list_bandwidthackages_response_body import ListBandwidthackagesResponseBody
from ._list_bandwidthackages_response import ListBandwidthackagesResponse
from ._list_basic_accelerate_ip_endpoint_relations_request import ListBasicAccelerateIpEndpointRelationsRequest
from ._list_basic_accelerate_ip_endpoint_relations_response_body import ListBasicAccelerateIpEndpointRelationsResponseBody
from ._list_basic_accelerate_ip_endpoint_relations_response import ListBasicAccelerateIpEndpointRelationsResponse
from ._list_basic_accelerate_ips_request import ListBasicAccelerateIpsRequest
from ._list_basic_accelerate_ips_response_body import ListBasicAccelerateIpsResponseBody
from ._list_basic_accelerate_ips_response import ListBasicAccelerateIpsResponse
from ._list_basic_accelerators_request import ListBasicAcceleratorsRequest
from ._list_basic_accelerators_response_body import ListBasicAcceleratorsResponseBody
from ._list_basic_accelerators_response import ListBasicAcceleratorsResponse
from ._list_basic_endpoints_request import ListBasicEndpointsRequest
from ._list_basic_endpoints_response_body import ListBasicEndpointsResponseBody
from ._list_basic_endpoints_response import ListBasicEndpointsResponse
from ._list_busi_regions_request import ListBusiRegionsRequest
from ._list_busi_regions_response_body import ListBusiRegionsResponseBody
from ._list_busi_regions_response import ListBusiRegionsResponse
from ._list_common_areas_request import ListCommonAreasRequest
from ._list_common_areas_response_body import ListCommonAreasResponseBody
from ._list_common_areas_response import ListCommonAreasResponse
from ._list_custom_routing_endpoint_group_destinations_request import ListCustomRoutingEndpointGroupDestinationsRequest
from ._list_custom_routing_endpoint_group_destinations_response_body import ListCustomRoutingEndpointGroupDestinationsResponseBody
from ._list_custom_routing_endpoint_group_destinations_response import ListCustomRoutingEndpointGroupDestinationsResponse
from ._list_custom_routing_endpoint_groups_request import ListCustomRoutingEndpointGroupsRequest
from ._list_custom_routing_endpoint_groups_response_body import ListCustomRoutingEndpointGroupsResponseBody
from ._list_custom_routing_endpoint_groups_response import ListCustomRoutingEndpointGroupsResponse
from ._list_custom_routing_endpoint_traffic_policies_request import ListCustomRoutingEndpointTrafficPoliciesRequest
from ._list_custom_routing_endpoint_traffic_policies_response_body import ListCustomRoutingEndpointTrafficPoliciesResponseBody
from ._list_custom_routing_endpoint_traffic_policies_response import ListCustomRoutingEndpointTrafficPoliciesResponse
from ._list_custom_routing_endpoints_request import ListCustomRoutingEndpointsRequest
from ._list_custom_routing_endpoints_response_body import ListCustomRoutingEndpointsResponseBody
from ._list_custom_routing_endpoints_response import ListCustomRoutingEndpointsResponse
from ._list_custom_routing_port_mappings_request import ListCustomRoutingPortMappingsRequest
from ._list_custom_routing_port_mappings_response_body import ListCustomRoutingPortMappingsResponseBody
from ._list_custom_routing_port_mappings_response import ListCustomRoutingPortMappingsResponse
from ._list_custom_routing_port_mappings_by_destination_request import ListCustomRoutingPortMappingsByDestinationRequest
from ._list_custom_routing_port_mappings_by_destination_response_body import ListCustomRoutingPortMappingsByDestinationResponseBody
from ._list_custom_routing_port_mappings_by_destination_response import ListCustomRoutingPortMappingsByDestinationResponse
from ._list_domains_request import ListDomainsRequest
from ._list_domains_response_body import ListDomainsResponseBody
from ._list_domains_response import ListDomainsResponse
from ._list_endpoint_group_ip_address_cidr_blocks_request import ListEndpointGroupIpAddressCidrBlocksRequest
from ._list_endpoint_group_ip_address_cidr_blocks_response_body import ListEndpointGroupIpAddressCidrBlocksResponseBody
from ._list_endpoint_group_ip_address_cidr_blocks_response import ListEndpointGroupIpAddressCidrBlocksResponse
from ._list_endpoint_groups_request import ListEndpointGroupsRequest
from ._list_endpoint_groups_response_body import ListEndpointGroupsResponseBody
from ._list_endpoint_groups_response import ListEndpointGroupsResponse
from ._list_forwarding_rules_request import ListForwardingRulesRequest
from ._list_forwarding_rules_response_body import ListForwardingRulesResponseBody
from ._list_forwarding_rules_response import ListForwardingRulesResponse
from ._list_ip_sets_request import ListIpSetsRequest
from ._list_ip_sets_response_body import ListIpSetsResponseBody
from ._list_ip_sets_response import ListIpSetsResponse
from ._list_isp_types_request import ListIspTypesRequest
from ._list_isp_types_response_body import ListIspTypesResponseBody
from ._list_isp_types_response import ListIspTypesResponse
from ._list_listener_certificates_request import ListListenerCertificatesRequest
from ._list_listener_certificates_response_body import ListListenerCertificatesResponseBody
from ._list_listener_certificates_response import ListListenerCertificatesResponse
from ._list_listeners_request import ListListenersRequest
from ._list_listeners_response_body import ListListenersResponseBody
from ._list_listeners_response import ListListenersResponse
from ._list_spare_ips_request import ListSpareIpsRequest
from ._list_spare_ips_response_body import ListSpareIpsResponseBody
from ._list_spare_ips_response import ListSpareIpsResponse
from ._list_system_security_policies_request import ListSystemSecurityPoliciesRequest
from ._list_system_security_policies_response_body import ListSystemSecurityPoliciesResponseBody
from ._list_system_security_policies_response import ListSystemSecurityPoliciesResponse
from ._list_tag_resources_request import ListTagResourcesRequest
from ._list_tag_resources_response_body import ListTagResourcesResponseBody
from ._list_tag_resources_response import ListTagResourcesResponse
from ._open_accelerator_service_request import OpenAcceleratorServiceRequest
from ._open_accelerator_service_response_body import OpenAcceleratorServiceResponseBody
from ._open_accelerator_service_response import OpenAcceleratorServiceResponse
from ._query_cross_border_approval_status_request import QueryCrossBorderApprovalStatusRequest
from ._query_cross_border_approval_status_response_body import QueryCrossBorderApprovalStatusResponseBody
from ._query_cross_border_approval_status_response import QueryCrossBorderApprovalStatusResponse
from ._remove_entries_from_acl_request import RemoveEntriesFromAclRequest
from ._remove_entries_from_acl_response_body import RemoveEntriesFromAclResponseBody
from ._remove_entries_from_acl_response import RemoveEntriesFromAclResponse
from ._replace_bandwidth_package_request import ReplaceBandwidthPackageRequest
from ._replace_bandwidth_package_response_body import ReplaceBandwidthPackageResponseBody
from ._replace_bandwidth_package_response import ReplaceBandwidthPackageResponse
from ._tag_resources_request import TagResourcesRequest
from ._tag_resources_response_body import TagResourcesResponseBody
from ._tag_resources_response import TagResourcesResponse
from ._untag_resources_request import UntagResourcesRequest
from ._untag_resources_response_body import UntagResourcesResponseBody
from ._untag_resources_response import UntagResourcesResponse
from ._update_accelerator_request import UpdateAcceleratorRequest
from ._update_accelerator_response_body import UpdateAcceleratorResponseBody
from ._update_accelerator_response import UpdateAcceleratorResponse
from ._update_accelerator_auto_renew_attribute_request import UpdateAcceleratorAutoRenewAttributeRequest
from ._update_accelerator_auto_renew_attribute_response_body import UpdateAcceleratorAutoRenewAttributeResponseBody
from ._update_accelerator_auto_renew_attribute_response import UpdateAcceleratorAutoRenewAttributeResponse
from ._update_accelerator_confirm_request import UpdateAcceleratorConfirmRequest
from ._update_accelerator_confirm_response_body import UpdateAcceleratorConfirmResponseBody
from ._update_accelerator_confirm_response import UpdateAcceleratorConfirmResponse
from ._update_accelerator_cross_border_mode_request import UpdateAcceleratorCrossBorderModeRequest
from ._update_accelerator_cross_border_mode_response_body import UpdateAcceleratorCrossBorderModeResponseBody
from ._update_accelerator_cross_border_mode_response import UpdateAcceleratorCrossBorderModeResponse
from ._update_accelerator_cross_border_status_request import UpdateAcceleratorCrossBorderStatusRequest
from ._update_accelerator_cross_border_status_response_body import UpdateAcceleratorCrossBorderStatusResponseBody
from ._update_accelerator_cross_border_status_response import UpdateAcceleratorCrossBorderStatusResponse
from ._update_acl_attribute_request import UpdateAclAttributeRequest
from ._update_acl_attribute_response_body import UpdateAclAttributeResponseBody
from ._update_acl_attribute_response import UpdateAclAttributeResponse
from ._update_additional_certificate_with_listener_request import UpdateAdditionalCertificateWithListenerRequest
from ._update_additional_certificate_with_listener_response_body import UpdateAdditionalCertificateWithListenerResponseBody
from ._update_additional_certificate_with_listener_response import UpdateAdditionalCertificateWithListenerResponse
from ._update_application_monitor_request import UpdateApplicationMonitorRequest
from ._update_application_monitor_response_body import UpdateApplicationMonitorResponseBody
from ._update_application_monitor_response import UpdateApplicationMonitorResponse
from ._update_bandwidth_packaga_auto_renew_attribute_request import UpdateBandwidthPackagaAutoRenewAttributeRequest
from ._update_bandwidth_packaga_auto_renew_attribute_response_body import UpdateBandwidthPackagaAutoRenewAttributeResponseBody
from ._update_bandwidth_packaga_auto_renew_attribute_response import UpdateBandwidthPackagaAutoRenewAttributeResponse
from ._update_bandwidth_package_request import UpdateBandwidthPackageRequest
from ._update_bandwidth_package_response_body import UpdateBandwidthPackageResponseBody
from ._update_bandwidth_package_response import UpdateBandwidthPackageResponse
from ._update_basic_accelerator_request import UpdateBasicAcceleratorRequest
from ._update_basic_accelerator_response_body import UpdateBasicAcceleratorResponseBody
from ._update_basic_accelerator_response import UpdateBasicAcceleratorResponse
from ._update_basic_endpoint_request import UpdateBasicEndpointRequest
from ._update_basic_endpoint_response_body import UpdateBasicEndpointResponseBody
from ._update_basic_endpoint_response import UpdateBasicEndpointResponse
from ._update_basic_endpoint_group_request import UpdateBasicEndpointGroupRequest
from ._update_basic_endpoint_group_response_body import UpdateBasicEndpointGroupResponseBody
from ._update_basic_endpoint_group_response import UpdateBasicEndpointGroupResponse
from ._update_basic_ip_set_request import UpdateBasicIpSetRequest
from ._update_basic_ip_set_response_body import UpdateBasicIpSetResponseBody
from ._update_basic_ip_set_response import UpdateBasicIpSetResponse
from ._update_custom_routing_endpoint_group_attribute_request import UpdateCustomRoutingEndpointGroupAttributeRequest
from ._update_custom_routing_endpoint_group_attribute_response_body import UpdateCustomRoutingEndpointGroupAttributeResponseBody
from ._update_custom_routing_endpoint_group_attribute_response import UpdateCustomRoutingEndpointGroupAttributeResponse
from ._update_custom_routing_endpoint_group_destinations_request import UpdateCustomRoutingEndpointGroupDestinationsRequest
from ._update_custom_routing_endpoint_group_destinations_response_body import UpdateCustomRoutingEndpointGroupDestinationsResponseBody
from ._update_custom_routing_endpoint_group_destinations_response import UpdateCustomRoutingEndpointGroupDestinationsResponse
from ._update_custom_routing_endpoint_traffic_policies_request import UpdateCustomRoutingEndpointTrafficPoliciesRequest
from ._update_custom_routing_endpoint_traffic_policies_response_body import UpdateCustomRoutingEndpointTrafficPoliciesResponseBody
from ._update_custom_routing_endpoint_traffic_policies_response import UpdateCustomRoutingEndpointTrafficPoliciesResponse
from ._update_custom_routing_endpoints_request import UpdateCustomRoutingEndpointsRequest
from ._update_custom_routing_endpoints_response_body import UpdateCustomRoutingEndpointsResponseBody
from ._update_custom_routing_endpoints_response import UpdateCustomRoutingEndpointsResponse
from ._update_domain_request import UpdateDomainRequest
from ._update_domain_response_body import UpdateDomainResponseBody
from ._update_domain_response import UpdateDomainResponse
from ._update_domain_state_request import UpdateDomainStateRequest
from ._update_domain_state_response_body import UpdateDomainStateResponseBody
from ._update_domain_state_response import UpdateDomainStateResponse
from ._update_endpoint_group_request import UpdateEndpointGroupRequest
from ._update_endpoint_group_response_body import UpdateEndpointGroupResponseBody
from ._update_endpoint_group_response import UpdateEndpointGroupResponse
from ._update_endpoint_group_attribute_request import UpdateEndpointGroupAttributeRequest
from ._update_endpoint_group_attribute_response_body import UpdateEndpointGroupAttributeResponseBody
from ._update_endpoint_group_attribute_response import UpdateEndpointGroupAttributeResponse
from ._update_endpoint_groups_request import UpdateEndpointGroupsRequest
from ._update_endpoint_groups_response_body import UpdateEndpointGroupsResponseBody
from ._update_endpoint_groups_response import UpdateEndpointGroupsResponse
from ._update_forwarding_rules_request import UpdateForwardingRulesRequest
from ._update_forwarding_rules_response_body import UpdateForwardingRulesResponseBody
from ._update_forwarding_rules_response import UpdateForwardingRulesResponse
from ._update_ip_set_request import UpdateIpSetRequest
from ._update_ip_set_response_body import UpdateIpSetResponseBody
from ._update_ip_set_response import UpdateIpSetResponse
from ._update_ip_sets_request import UpdateIpSetsRequest
from ._update_ip_sets_response_body import UpdateIpSetsResponseBody
from ._update_ip_sets_response import UpdateIpSetsResponse
from ._update_listener_request import UpdateListenerRequest
from ._update_listener_response_body import UpdateListenerResponseBody
from ._update_listener_response import UpdateListenerResponse
from ._update_log_store_config_request import UpdateLogStoreConfigRequest
from ._update_log_store_config_response_body import UpdateLogStoreConfigResponseBody
from ._update_log_store_config_response import UpdateLogStoreConfigResponse
from ._update_service_managed_control_request import UpdateServiceManagedControlRequest
from ._update_service_managed_control_response_body import UpdateServiceManagedControlResponseBody
from ._update_service_managed_control_response import UpdateServiceManagedControlResponse
from ._add_entries_to_acl_request import AddEntriesToAclRequestAclEntries
from ._associate_additional_certificates_with_listener_request import AssociateAdditionalCertificatesWithListenerRequestCertificates
from ._attach_ddos_to_accelerator_request import AttachDdosToAcceleratorRequestDdosConfigList
from ._create_accelerator_request import CreateAcceleratorRequestIpSetConfig
from ._create_accelerator_request import CreateAcceleratorRequestTag
from ._create_acl_request import CreateAclRequestAclEntries
from ._create_acl_request import CreateAclRequestTag
from ._create_bandwidth_package_request import CreateBandwidthPackageRequestTag
from ._create_basic_accelerate_ip_endpoint_relations_request import CreateBasicAccelerateIpEndpointRelationsRequestAccelerateIpEndpointRelations
from ._create_basic_accelerator_request import CreateBasicAcceleratorRequestTag
from ._create_basic_endpoints_request import CreateBasicEndpointsRequestEndpoints
from ._create_basic_endpoints_response_body import CreateBasicEndpointsResponseBodyEndpoints
from ._create_custom_routing_endpoint_group_destinations_request import CreateCustomRoutingEndpointGroupDestinationsRequestDestinationConfigurations
from ._create_custom_routing_endpoint_groups_request import CreateCustomRoutingEndpointGroupsRequestEndpointGroupConfigurationsDestinationConfigurations
from ._create_custom_routing_endpoint_groups_request import CreateCustomRoutingEndpointGroupsRequestEndpointGroupConfigurationsEndpointConfigurationsPolicyConfigurationsPortRanges
from ._create_custom_routing_endpoint_groups_request import CreateCustomRoutingEndpointGroupsRequestEndpointGroupConfigurationsEndpointConfigurationsPolicyConfigurations
from ._create_custom_routing_endpoint_groups_request import CreateCustomRoutingEndpointGroupsRequestEndpointGroupConfigurationsEndpointConfigurations
from ._create_custom_routing_endpoint_groups_request import CreateCustomRoutingEndpointGroupsRequestEndpointGroupConfigurations
from ._create_custom_routing_endpoint_traffic_policies_request import CreateCustomRoutingEndpointTrafficPoliciesRequestPolicyConfigurationsPortRanges
from ._create_custom_routing_endpoint_traffic_policies_request import CreateCustomRoutingEndpointTrafficPoliciesRequestPolicyConfigurations
from ._create_custom_routing_endpoints_request import CreateCustomRoutingEndpointsRequestEndpointConfigurationsPolicyConfigurationsPortRanges
from ._create_custom_routing_endpoints_request import CreateCustomRoutingEndpointsRequestEndpointConfigurationsPolicyConfigurations
from ._create_custom_routing_endpoints_request import CreateCustomRoutingEndpointsRequestEndpointConfigurations
from ._create_endpoint_group_request import CreateEndpointGroupRequestEndpointConfigurations
from ._create_endpoint_group_request import CreateEndpointGroupRequestPortOverrides
from ._create_endpoint_group_request import CreateEndpointGroupRequestTag
from ._create_endpoint_groups_request import CreateEndpointGroupsRequestEndpointGroupConfigurationsEndpointConfigurations
from ._create_endpoint_groups_request import CreateEndpointGroupsRequestEndpointGroupConfigurationsPortOverrides
from ._create_endpoint_groups_request import CreateEndpointGroupsRequestEndpointGroupConfigurationsSystemTag
from ._create_endpoint_groups_request import CreateEndpointGroupsRequestEndpointGroupConfigurationsTag
from ._create_endpoint_groups_request import CreateEndpointGroupsRequestEndpointGroupConfigurations
from ._create_forwarding_rules_request import CreateForwardingRulesRequestForwardingRulesRuleActionsForwardGroupConfigServerGroupTuples
from ._create_forwarding_rules_request import CreateForwardingRulesRequestForwardingRulesRuleActionsForwardGroupConfig
from ._create_forwarding_rules_request import CreateForwardingRulesRequestForwardingRulesRuleActions
from ._create_forwarding_rules_request import CreateForwardingRulesRequestForwardingRulesRuleConditionsHostConfig
from ._create_forwarding_rules_request import CreateForwardingRulesRequestForwardingRulesRuleConditionsPathConfig
from ._create_forwarding_rules_request import CreateForwardingRulesRequestForwardingRulesRuleConditions
from ._create_forwarding_rules_request import CreateForwardingRulesRequestForwardingRules
from ._create_forwarding_rules_response_body import CreateForwardingRulesResponseBodyForwardingRules
from ._create_ip_sets_request import CreateIpSetsRequestAccelerateRegion
from ._create_ip_sets_response_body import CreateIpSetsResponseBodyIpSets
from ._create_listener_request import CreateListenerRequestCertificates
from ._create_listener_request import CreateListenerRequestCustomRoutingEndpointGroupConfigurationsDestinationConfigurations
from ._create_listener_request import CreateListenerRequestCustomRoutingEndpointGroupConfigurationsEndpointConfigurationsPolicyConfigurationsPortRanges
from ._create_listener_request import CreateListenerRequestCustomRoutingEndpointGroupConfigurationsEndpointConfigurationsPolicyConfigurations
from ._create_listener_request import CreateListenerRequestCustomRoutingEndpointGroupConfigurationsEndpointConfigurations
from ._create_listener_request import CreateListenerRequestCustomRoutingEndpointGroupConfigurations
from ._create_listener_request import CreateListenerRequestEndpointGroupConfigurationsEndpointConfigurations
from ._create_listener_request import CreateListenerRequestEndpointGroupConfigurationsPortOverrides
from ._create_listener_request import CreateListenerRequestEndpointGroupConfigurations
from ._create_listener_request import CreateListenerRequestPortRanges
from ._create_listener_request import CreateListenerRequestXForwardedForConfig
from ._delete_forwarding_rules_response_body import DeleteForwardingRulesResponseBodyForwardingRules
from ._describe_accelerator_response_body import DescribeAcceleratorResponseBodyBasicBandwidthPackage
from ._describe_accelerator_response_body import DescribeAcceleratorResponseBodyCrossDomainBandwidthPackage
from ._describe_accelerator_response_body import DescribeAcceleratorResponseBodyDdosConfigList
from ._describe_accelerator_response_body import DescribeAcceleratorResponseBodyIpSetConfig
from ._describe_accelerator_response_body import DescribeAcceleratorResponseBodyServiceManagedInfos
from ._describe_accelerator_response_body import DescribeAcceleratorResponseBodyTags
from ._describe_application_monitor_response_body import DescribeApplicationMonitorResponseBodyIspCityList
from ._describe_bandwidth_package_response_body import DescribeBandwidthPackageResponseBodyTags
from ._describe_commodity_response_body import DescribeCommodityResponseBodyComponentsPropertiesPropertyValueList
from ._describe_commodity_response_body import DescribeCommodityResponseBodyComponentsProperties
from ._describe_commodity_response_body import DescribeCommodityResponseBodyComponents
from ._describe_commodity_price_request import DescribeCommodityPriceRequestOrdersComponentsProperties
from ._describe_commodity_price_request import DescribeCommodityPriceRequestOrdersComponents
from ._describe_commodity_price_request import DescribeCommodityPriceRequestOrders
from ._describe_commodity_price_response_body import DescribeCommodityPriceResponseBodyOrderDetailsModuleDetails
from ._describe_commodity_price_response_body import DescribeCommodityPriceResponseBodyOrderDetailsPromDetails
from ._describe_commodity_price_response_body import DescribeCommodityPriceResponseBodyOrderDetails
from ._describe_commodity_price_response_body import DescribeCommodityPriceResponseBodyPromotions
from ._describe_commodity_price_response_body import DescribeCommodityPriceResponseBodyRuleDetails
from ._describe_custom_routing_end_point_traffic_policy_response_body import DescribeCustomRoutingEndPointTrafficPolicyResponseBodyPortRanges
from ._describe_custom_routing_end_point_traffic_policy_response_body import DescribeCustomRoutingEndPointTrafficPolicyResponseBodyServiceManagedInfos
from ._describe_custom_routing_endpoint_response_body import DescribeCustomRoutingEndpointResponseBodyServiceManagedInfos
from ._describe_custom_routing_endpoint_group_response_body import DescribeCustomRoutingEndpointGroupResponseBodyServiceManagedInfos
from ._describe_custom_routing_endpoint_group_destinations_response_body import DescribeCustomRoutingEndpointGroupDestinationsResponseBodyServiceManagedInfos
from ._describe_endpoint_group_response_body import DescribeEndpointGroupResponseBodyEndpointConfigurations
from ._describe_endpoint_group_response_body import DescribeEndpointGroupResponseBodyEndpointPrivateIpList
from ._describe_endpoint_group_response_body import DescribeEndpointGroupResponseBodyPortOverrides
from ._describe_endpoint_group_response_body import DescribeEndpointGroupResponseBodyServiceManagedInfos
from ._describe_endpoint_group_response_body import DescribeEndpointGroupResponseBodyTags
from ._describe_ip_set_response_body import DescribeIpSetResponseBodyServiceManagedInfos
from ._describe_listener_response_body import DescribeListenerResponseBodyBackendPorts
from ._describe_listener_response_body import DescribeListenerResponseBodyCertificates
from ._describe_listener_response_body import DescribeListenerResponseBodyPortRanges
from ._describe_listener_response_body import DescribeListenerResponseBodyRelatedAcls
from ._describe_listener_response_body import DescribeListenerResponseBodyServiceManagedInfos
from ._describe_listener_response_body import DescribeListenerResponseBodyXForwardedForConfig
from ._describe_regions_response_body import DescribeRegionsResponseBodyRegions
from ._detach_ddos_from_accelerator_request import DetachDdosFromAcceleratorRequestDdosConfigList
from ._get_acl_response_body import GetAclResponseBodyAclEntries
from ._get_acl_response_body import GetAclResponseBodyRelatedListeners
from ._get_acl_response_body import GetAclResponseBodyTags
from ._get_basic_accelerator_response_body import GetBasicAcceleratorResponseBodyBasicBandwidthPackage
from ._get_basic_accelerator_response_body import GetBasicAcceleratorResponseBodyCrossDomainBandwidthPackage
from ._get_basic_accelerator_response_body import GetBasicAcceleratorResponseBodyTags
from ._get_global_accelerator_resources_response_body import GetGlobalAcceleratorResourcesResponseBodyAssociatedResources
from ._get_health_status_response_body import GetHealthStatusResponseBodyEndpointGroupsEndpoints
from ._get_health_status_response_body import GetHealthStatusResponseBodyEndpointGroups
from ._list_accelerate_areas_response_body import ListAccelerateAreasResponseBodyAreasRegionList
from ._list_accelerate_areas_response_body import ListAccelerateAreasResponseBodyAreas
from ._list_accelerators_request import ListAcceleratorsRequestTag
from ._list_accelerators_response_body import ListAcceleratorsResponseBodyAcceleratorsBasicBandwidthPackage
from ._list_accelerators_response_body import ListAcceleratorsResponseBodyAcceleratorsCrossDomainBandwidthPackage
from ._list_accelerators_response_body import ListAcceleratorsResponseBodyAcceleratorsDdosConfigList
from ._list_accelerators_response_body import ListAcceleratorsResponseBodyAcceleratorsIpSetConfig
from ._list_accelerators_response_body import ListAcceleratorsResponseBodyAcceleratorsServiceManagedInfos
from ._list_accelerators_response_body import ListAcceleratorsResponseBodyAcceleratorsTags
from ._list_accelerators_response_body import ListAcceleratorsResponseBodyAccelerators
from ._list_acls_request import ListAclsRequestTag
from ._list_acls_response_body import ListAclsResponseBodyAclsTags
from ._list_acls_response_body import ListAclsResponseBodyAcls
from ._list_application_monitor_response_body import ListApplicationMonitorResponseBodyApplicationMonitors
from ._list_application_monitor_detect_result_response_body import ListApplicationMonitorDetectResultResponseBodyApplicationMonitorDetectResultList
from ._list_available_accelerate_areas_response_body import ListAvailableAccelerateAreasResponseBodyAreasRegionList
from ._list_available_accelerate_areas_response_body import ListAvailableAccelerateAreasResponseBodyAreas
from ._list_available_busi_regions_response_body import ListAvailableBusiRegionsResponseBodyRegions
from ._list_bandwidth_packages_request import ListBandwidthPackagesRequestTag
from ._list_bandwidth_packages_response_body import ListBandwidthPackagesResponseBodyBandwidthPackagesTags
from ._list_bandwidth_packages_response_body import ListBandwidthPackagesResponseBodyBandwidthPackages
from ._list_bandwidthackages_response_body import ListBandwidthackagesResponseBodyBandwidthPackagesTags
from ._list_bandwidthackages_response_body import ListBandwidthackagesResponseBodyBandwidthPackages
from ._list_basic_accelerate_ip_endpoint_relations_response_body import ListBasicAccelerateIpEndpointRelationsResponseBodyAccelerateIpEndpointRelations
from ._list_basic_accelerate_ips_response_body import ListBasicAccelerateIpsResponseBodyAccelerateIps
from ._list_basic_accelerators_request import ListBasicAcceleratorsRequestTag
from ._list_basic_accelerators_response_body import ListBasicAcceleratorsResponseBodyAcceleratorsBasicBandwidthPackage
from ._list_basic_accelerators_response_body import ListBasicAcceleratorsResponseBodyAcceleratorsCrossDomainBandwidthPackage
from ._list_basic_accelerators_response_body import ListBasicAcceleratorsResponseBodyAcceleratorsTags
from ._list_basic_accelerators_response_body import ListBasicAcceleratorsResponseBodyAccelerators
from ._list_basic_endpoints_response_body import ListBasicEndpointsResponseBodyEndpoints
from ._list_busi_regions_response_body import ListBusiRegionsResponseBodyRegions
from ._list_common_areas_response_body import ListCommonAreasResponseBodyAreasRegionList
from ._list_common_areas_response_body import ListCommonAreasResponseBodyAreas
from ._list_custom_routing_endpoint_group_destinations_response_body import ListCustomRoutingEndpointGroupDestinationsResponseBodyDestinationsServiceManagedInfos
from ._list_custom_routing_endpoint_group_destinations_response_body import ListCustomRoutingEndpointGroupDestinationsResponseBodyDestinations
from ._list_custom_routing_endpoint_groups_response_body import ListCustomRoutingEndpointGroupsResponseBodyEndpointGroupsServiceManagedInfos
from ._list_custom_routing_endpoint_groups_response_body import ListCustomRoutingEndpointGroupsResponseBodyEndpointGroups
from ._list_custom_routing_endpoint_traffic_policies_response_body import ListCustomRoutingEndpointTrafficPoliciesResponseBodyPoliciesPortRanges
from ._list_custom_routing_endpoint_traffic_policies_response_body import ListCustomRoutingEndpointTrafficPoliciesResponseBodyPoliciesServiceManagedInfos
from ._list_custom_routing_endpoint_traffic_policies_response_body import ListCustomRoutingEndpointTrafficPoliciesResponseBodyPolicies
from ._list_custom_routing_endpoints_response_body import ListCustomRoutingEndpointsResponseBodyEndpointsServiceManagedInfos
from ._list_custom_routing_endpoints_response_body import ListCustomRoutingEndpointsResponseBodyEndpoints
from ._list_custom_routing_port_mappings_response_body import ListCustomRoutingPortMappingsResponseBodyPortMappingsDestinationSocketAddress
from ._list_custom_routing_port_mappings_response_body import ListCustomRoutingPortMappingsResponseBodyPortMappings
from ._list_custom_routing_port_mappings_by_destination_response_body import ListCustomRoutingPortMappingsByDestinationResponseBodyPortMappingsDestinationSocketAddress
from ._list_custom_routing_port_mappings_by_destination_response_body import ListCustomRoutingPortMappingsByDestinationResponseBodyPortMappings
from ._list_domains_response_body import ListDomainsResponseBodyDomainsAcceleratorsServiceManagedInfos
from ._list_domains_response_body import ListDomainsResponseBodyDomainsAccelerators
from ._list_domains_response_body import ListDomainsResponseBodyDomains
from ._list_endpoint_groups_request import ListEndpointGroupsRequestTag
from ._list_endpoint_groups_response_body import ListEndpointGroupsResponseBodyEndpointGroupsEndpointConfigurations
from ._list_endpoint_groups_response_body import ListEndpointGroupsResponseBodyEndpointGroupsEndpointPrivateIpList
from ._list_endpoint_groups_response_body import ListEndpointGroupsResponseBodyEndpointGroupsPortOverrides
from ._list_endpoint_groups_response_body import ListEndpointGroupsResponseBodyEndpointGroupsServiceManagedInfos
from ._list_endpoint_groups_response_body import ListEndpointGroupsResponseBodyEndpointGroupsTags
from ._list_endpoint_groups_response_body import ListEndpointGroupsResponseBodyEndpointGroups
from ._list_forwarding_rules_response_body import ListForwardingRulesResponseBodyForwardingRulesRuleActionsForwardGroupConfigServerGroupTuples
from ._list_forwarding_rules_response_body import ListForwardingRulesResponseBodyForwardingRulesRuleActionsForwardGroupConfig
from ._list_forwarding_rules_response_body import ListForwardingRulesResponseBodyForwardingRulesRuleActions
from ._list_forwarding_rules_response_body import ListForwardingRulesResponseBodyForwardingRulesRuleConditionsHostConfig
from ._list_forwarding_rules_response_body import ListForwardingRulesResponseBodyForwardingRulesRuleConditionsPathConfig
from ._list_forwarding_rules_response_body import ListForwardingRulesResponseBodyForwardingRulesRuleConditions
from ._list_forwarding_rules_response_body import ListForwardingRulesResponseBodyForwardingRulesServiceManagedInfos
from ._list_forwarding_rules_response_body import ListForwardingRulesResponseBodyForwardingRules
from ._list_ip_sets_response_body import ListIpSetsResponseBodyIpSetsServiceManagedInfos
from ._list_ip_sets_response_body import ListIpSetsResponseBodyIpSets
from ._list_listener_certificates_response_body import ListListenerCertificatesResponseBodyCertificates
from ._list_listeners_response_body import ListListenersResponseBodyListenersBackendPorts
from ._list_listeners_response_body import ListListenersResponseBodyListenersCertificates
from ._list_listeners_response_body import ListListenersResponseBodyListenersPortRanges
from ._list_listeners_response_body import ListListenersResponseBodyListenersServiceManagedInfos
from ._list_listeners_response_body import ListListenersResponseBodyListenersXForwardedForConfig
from ._list_listeners_response_body import ListListenersResponseBodyListeners
from ._list_spare_ips_response_body import ListSpareIpsResponseBodySpareIps
from ._list_system_security_policies_response_body import ListSystemSecurityPoliciesResponseBodySecurityPolicies
from ._list_tag_resources_request import ListTagResourcesRequestTag
from ._list_tag_resources_response_body import ListTagResourcesResponseBodyTagResourcesTagResource
from ._list_tag_resources_response_body import ListTagResourcesResponseBodyTagResources
from ._remove_entries_from_acl_request import RemoveEntriesFromAclRequestAclEntries
from ._tag_resources_request import TagResourcesRequestTag
from ._update_custom_routing_endpoint_group_destinations_request import UpdateCustomRoutingEndpointGroupDestinationsRequestDestinationConfigurations
from ._update_custom_routing_endpoint_traffic_policies_request import UpdateCustomRoutingEndpointTrafficPoliciesRequestPolicyConfigurationsPortRanges
from ._update_custom_routing_endpoint_traffic_policies_request import UpdateCustomRoutingEndpointTrafficPoliciesRequestPolicyConfigurations
from ._update_custom_routing_endpoints_request import UpdateCustomRoutingEndpointsRequestEndpointConfigurationsPolicyConfigurationsPortRanges
from ._update_custom_routing_endpoints_request import UpdateCustomRoutingEndpointsRequestEndpointConfigurationsPolicyConfigurations
from ._update_custom_routing_endpoints_request import UpdateCustomRoutingEndpointsRequestEndpointConfigurations
from ._update_endpoint_group_request import UpdateEndpointGroupRequestEndpointConfigurations
from ._update_endpoint_group_request import UpdateEndpointGroupRequestPortOverrides
from ._update_endpoint_groups_request import UpdateEndpointGroupsRequestEndpointGroupConfigurationsEndpointConfigurations
from ._update_endpoint_groups_request import UpdateEndpointGroupsRequestEndpointGroupConfigurationsPortOverrides
from ._update_endpoint_groups_request import UpdateEndpointGroupsRequestEndpointGroupConfigurations
from ._update_forwarding_rules_request import UpdateForwardingRulesRequestForwardingRulesRuleActionsForwardGroupConfigServerGroupTuples
from ._update_forwarding_rules_request import UpdateForwardingRulesRequestForwardingRulesRuleActionsForwardGroupConfig
from ._update_forwarding_rules_request import UpdateForwardingRulesRequestForwardingRulesRuleActions
from ._update_forwarding_rules_request import UpdateForwardingRulesRequestForwardingRulesRuleConditionsHostConfig
from ._update_forwarding_rules_request import UpdateForwardingRulesRequestForwardingRulesRuleConditionsPathConfig
from ._update_forwarding_rules_request import UpdateForwardingRulesRequestForwardingRulesRuleConditions
from ._update_forwarding_rules_request import UpdateForwardingRulesRequestForwardingRules
from ._update_forwarding_rules_response_body import UpdateForwardingRulesResponseBodyForwardingRules
from ._update_ip_sets_request import UpdateIpSetsRequestIpSets
from ._update_listener_request import UpdateListenerRequestBackendPorts
from ._update_listener_request import UpdateListenerRequestCertificates
from ._update_listener_request import UpdateListenerRequestPortRanges
from ._update_listener_request import UpdateListenerRequestXForwardedForConfig

__all__ = [
    AddEntriesToAclRequest,
    AddEntriesToAclResponseBody,
    AddEntriesToAclResponse,
    AssociateAclsWithListenerRequest,
    AssociateAclsWithListenerResponseBody,
    AssociateAclsWithListenerResponse,
    AssociateAdditionalCertificatesWithListenerRequest,
    AssociateAdditionalCertificatesWithListenerResponseBody,
    AssociateAdditionalCertificatesWithListenerResponse,
    AssociateResourcesRequest,
    AssociateResourcesResponseBody,
    AssociateResourcesResponse,
    AttachDdosToAcceleratorRequest,
    AttachDdosToAcceleratorResponseBody,
    AttachDdosToAcceleratorResponse,
    AttachLogStoreToEndpointGroupRequest,
    AttachLogStoreToEndpointGroupResponseBody,
    AttachLogStoreToEndpointGroupResponse,
    BandwidthPackageAddAcceleratorRequest,
    BandwidthPackageAddAcceleratorResponseBody,
    BandwidthPackageAddAcceleratorResponse,
    BandwidthPackageRemoveAcceleratorRequest,
    BandwidthPackageRemoveAcceleratorResponseBody,
    BandwidthPackageRemoveAcceleratorResponse,
    ChangeResourceGroupRequest,
    ChangeResourceGroupResponseBody,
    ChangeResourceGroupResponse,
    ConfigEndpointProbeRequest,
    ConfigEndpointProbeResponseBody,
    ConfigEndpointProbeResponse,
    CreateAcceleratorRequest,
    CreateAcceleratorResponseBody,
    CreateAcceleratorResponse,
    CreateAclRequest,
    CreateAclResponseBody,
    CreateAclResponse,
    CreateApplicationMonitorRequest,
    CreateApplicationMonitorResponseBody,
    CreateApplicationMonitorResponse,
    CreateBandwidthPackageRequest,
    CreateBandwidthPackageResponseBody,
    CreateBandwidthPackageResponse,
    CreateBasicAccelerateIpRequest,
    CreateBasicAccelerateIpResponseBody,
    CreateBasicAccelerateIpResponse,
    CreateBasicAccelerateIpEndpointRelationRequest,
    CreateBasicAccelerateIpEndpointRelationResponseBody,
    CreateBasicAccelerateIpEndpointRelationResponse,
    CreateBasicAccelerateIpEndpointRelationsRequest,
    CreateBasicAccelerateIpEndpointRelationsResponseBody,
    CreateBasicAccelerateIpEndpointRelationsResponse,
    CreateBasicAcceleratorRequest,
    CreateBasicAcceleratorResponseBody,
    CreateBasicAcceleratorResponse,
    CreateBasicEndpointRequest,
    CreateBasicEndpointResponseBody,
    CreateBasicEndpointResponse,
    CreateBasicEndpointGroupRequest,
    CreateBasicEndpointGroupResponseBody,
    CreateBasicEndpointGroupResponse,
    CreateBasicEndpointsRequest,
    CreateBasicEndpointsResponseBody,
    CreateBasicEndpointsResponse,
    CreateBasicIpSetRequest,
    CreateBasicIpSetResponseBody,
    CreateBasicIpSetResponse,
    CreateCustomRoutingEndpointGroupDestinationsRequest,
    CreateCustomRoutingEndpointGroupDestinationsResponseBody,
    CreateCustomRoutingEndpointGroupDestinationsResponse,
    CreateCustomRoutingEndpointGroupsRequest,
    CreateCustomRoutingEndpointGroupsResponseBody,
    CreateCustomRoutingEndpointGroupsResponse,
    CreateCustomRoutingEndpointTrafficPoliciesRequest,
    CreateCustomRoutingEndpointTrafficPoliciesResponseBody,
    CreateCustomRoutingEndpointTrafficPoliciesResponse,
    CreateCustomRoutingEndpointsRequest,
    CreateCustomRoutingEndpointsResponseBody,
    CreateCustomRoutingEndpointsResponse,
    CreateDomainRequest,
    CreateDomainResponseBody,
    CreateDomainResponse,
    CreateEndpointGroupRequest,
    CreateEndpointGroupResponseBody,
    CreateEndpointGroupResponse,
    CreateEndpointGroupsRequest,
    CreateEndpointGroupsResponseBody,
    CreateEndpointGroupsResponse,
    CreateForwardingRulesRequest,
    CreateForwardingRulesResponseBody,
    CreateForwardingRulesResponse,
    CreateIpSetsRequest,
    CreateIpSetsResponseBody,
    CreateIpSetsResponse,
    CreateListenerRequest,
    CreateListenerResponseBody,
    CreateListenerResponse,
    CreateSpareIpsRequest,
    CreateSpareIpsResponseBody,
    CreateSpareIpsResponse,
    DeleteAcceleratorRequest,
    DeleteAcceleratorResponseBody,
    DeleteAcceleratorResponse,
    DeleteAclRequest,
    DeleteAclResponseBody,
    DeleteAclResponse,
    DeleteApplicationMonitorRequest,
    DeleteApplicationMonitorResponseBody,
    DeleteApplicationMonitorResponse,
    DeleteBandwidthPackageRequest,
    DeleteBandwidthPackageResponseBody,
    DeleteBandwidthPackageResponse,
    DeleteBasicAccelerateIpRequest,
    DeleteBasicAccelerateIpResponseBody,
    DeleteBasicAccelerateIpResponse,
    DeleteBasicAccelerateIpEndpointRelationRequest,
    DeleteBasicAccelerateIpEndpointRelationResponseBody,
    DeleteBasicAccelerateIpEndpointRelationResponse,
    DeleteBasicAcceleratorRequest,
    DeleteBasicAcceleratorResponseBody,
    DeleteBasicAcceleratorResponse,
    DeleteBasicEndpointRequest,
    DeleteBasicEndpointResponseBody,
    DeleteBasicEndpointResponse,
    DeleteBasicEndpointGroupRequest,
    DeleteBasicEndpointGroupResponseBody,
    DeleteBasicEndpointGroupResponse,
    DeleteBasicIpSetRequest,
    DeleteBasicIpSetResponseBody,
    DeleteBasicIpSetResponse,
    DeleteCustomRoutingEndpointGroupDestinationsRequest,
    DeleteCustomRoutingEndpointGroupDestinationsResponseBody,
    DeleteCustomRoutingEndpointGroupDestinationsResponse,
    DeleteCustomRoutingEndpointGroupsRequest,
    DeleteCustomRoutingEndpointGroupsResponseBody,
    DeleteCustomRoutingEndpointGroupsResponse,
    DeleteCustomRoutingEndpointTrafficPoliciesRequest,
    DeleteCustomRoutingEndpointTrafficPoliciesResponseBody,
    DeleteCustomRoutingEndpointTrafficPoliciesResponse,
    DeleteCustomRoutingEndpointsRequest,
    DeleteCustomRoutingEndpointsResponseBody,
    DeleteCustomRoutingEndpointsResponse,
    DeleteDomainAcceleratorRelationRequest,
    DeleteDomainAcceleratorRelationResponseBody,
    DeleteDomainAcceleratorRelationResponse,
    DeleteEndpointGroupRequest,
    DeleteEndpointGroupResponseBody,
    DeleteEndpointGroupResponse,
    DeleteEndpointGroupsRequest,
    DeleteEndpointGroupsResponseBody,
    DeleteEndpointGroupsResponse,
    DeleteForwardingRulesRequest,
    DeleteForwardingRulesResponseBody,
    DeleteForwardingRulesResponse,
    DeleteIpSetRequest,
    DeleteIpSetResponseBody,
    DeleteIpSetResponse,
    DeleteIpSetsRequest,
    DeleteIpSetsResponseBody,
    DeleteIpSetsResponse,
    DeleteListenerRequest,
    DeleteListenerResponseBody,
    DeleteListenerResponse,
    DeleteSpareIpsRequest,
    DeleteSpareIpsResponseBody,
    DeleteSpareIpsResponse,
    DescribeAcceleratorRequest,
    DescribeAcceleratorResponseBody,
    DescribeAcceleratorResponse,
    DescribeAcceleratorAutoRenewAttributeRequest,
    DescribeAcceleratorAutoRenewAttributeResponseBody,
    DescribeAcceleratorAutoRenewAttributeResponse,
    DescribeAcceleratorServiceStatusRequest,
    DescribeAcceleratorServiceStatusResponseBody,
    DescribeAcceleratorServiceStatusResponse,
    DescribeApplicationMonitorRequest,
    DescribeApplicationMonitorResponseBody,
    DescribeApplicationMonitorResponse,
    DescribeBandwidthPackageRequest,
    DescribeBandwidthPackageResponseBody,
    DescribeBandwidthPackageResponse,
    DescribeBandwidthPackageAutoRenewAttributeRequest,
    DescribeBandwidthPackageAutoRenewAttributeResponseBody,
    DescribeBandwidthPackageAutoRenewAttributeResponse,
    DescribeCommodityRequest,
    DescribeCommodityResponseBody,
    DescribeCommodityResponse,
    DescribeCommodityPriceRequest,
    DescribeCommodityPriceResponseBody,
    DescribeCommodityPriceResponse,
    DescribeCustomRoutingEndPointTrafficPolicyRequest,
    DescribeCustomRoutingEndPointTrafficPolicyResponseBody,
    DescribeCustomRoutingEndPointTrafficPolicyResponse,
    DescribeCustomRoutingEndpointRequest,
    DescribeCustomRoutingEndpointResponseBody,
    DescribeCustomRoutingEndpointResponse,
    DescribeCustomRoutingEndpointGroupRequest,
    DescribeCustomRoutingEndpointGroupResponseBody,
    DescribeCustomRoutingEndpointGroupResponse,
    DescribeCustomRoutingEndpointGroupDestinationsRequest,
    DescribeCustomRoutingEndpointGroupDestinationsResponseBody,
    DescribeCustomRoutingEndpointGroupDestinationsResponse,
    DescribeEndpointGroupRequest,
    DescribeEndpointGroupResponseBody,
    DescribeEndpointGroupResponse,
    DescribeIpSetRequest,
    DescribeIpSetResponseBody,
    DescribeIpSetResponse,
    DescribeListenerRequest,
    DescribeListenerResponseBody,
    DescribeListenerResponse,
    DescribeLogStoreOfEndpointGroupRequest,
    DescribeLogStoreOfEndpointGroupResponseBody,
    DescribeLogStoreOfEndpointGroupResponse,
    DescribeRegionsRequest,
    DescribeRegionsResponseBody,
    DescribeRegionsResponse,
    DetachDdosFromAcceleratorRequest,
    DetachDdosFromAcceleratorResponseBody,
    DetachDdosFromAcceleratorResponse,
    DetachLogStoreFromEndpointGroupRequest,
    DetachLogStoreFromEndpointGroupResponseBody,
    DetachLogStoreFromEndpointGroupResponse,
    DetectApplicationMonitorRequest,
    DetectApplicationMonitorResponseBody,
    DetectApplicationMonitorResponse,
    DisableApplicationMonitorRequest,
    DisableApplicationMonitorResponseBody,
    DisableApplicationMonitorResponse,
    DisassociateResourcesRequest,
    DisassociateResourcesResponseBody,
    DisassociateResourcesResponse,
    DissociateAclsFromListenerRequest,
    DissociateAclsFromListenerResponseBody,
    DissociateAclsFromListenerResponse,
    DissociateAdditionalCertificatesFromListenerRequest,
    DissociateAdditionalCertificatesFromListenerResponseBody,
    DissociateAdditionalCertificatesFromListenerResponse,
    EnableApplicationMonitorRequest,
    EnableApplicationMonitorResponseBody,
    EnableApplicationMonitorResponse,
    GetAclRequest,
    GetAclResponseBody,
    GetAclResponse,
    GetBasicAccelerateIpRequest,
    GetBasicAccelerateIpResponseBody,
    GetBasicAccelerateIpResponse,
    GetBasicAccelerateIpEndpointRelationRequest,
    GetBasicAccelerateIpEndpointRelationResponseBody,
    GetBasicAccelerateIpEndpointRelationResponse,
    GetBasicAccelerateIpIdleCountRequest,
    GetBasicAccelerateIpIdleCountResponseBody,
    GetBasicAccelerateIpIdleCountResponse,
    GetBasicAcceleratorRequest,
    GetBasicAcceleratorResponseBody,
    GetBasicAcceleratorResponse,
    GetBasicEndpointRequest,
    GetBasicEndpointResponseBody,
    GetBasicEndpointResponse,
    GetBasicEndpointGroupRequest,
    GetBasicEndpointGroupResponseBody,
    GetBasicEndpointGroupResponse,
    GetBasicIpSetRequest,
    GetBasicIpSetResponseBody,
    GetBasicIpSetResponse,
    GetGlobalAcceleratorResourcesRequest,
    GetGlobalAcceleratorResourcesResponseBody,
    GetGlobalAcceleratorResourcesResponse,
    GetHealthStatusRequest,
    GetHealthStatusResponseBody,
    GetHealthStatusResponse,
    GetInvalidDomainCountRequest,
    GetInvalidDomainCountResponseBody,
    GetInvalidDomainCountResponse,
    GetIpsetsBandwidthLimitRequest,
    GetIpsetsBandwidthLimitResponseBody,
    GetIpsetsBandwidthLimitResponse,
    GetSpareIpRequest,
    GetSpareIpResponseBody,
    GetSpareIpResponse,
    ListAccelerateAreasRequest,
    ListAccelerateAreasResponseBody,
    ListAccelerateAreasResponse,
    ListAcceleratorsRequest,
    ListAcceleratorsResponseBody,
    ListAcceleratorsResponse,
    ListAclsRequest,
    ListAclsResponseBody,
    ListAclsResponse,
    ListApplicationMonitorRequest,
    ListApplicationMonitorResponseBody,
    ListApplicationMonitorResponse,
    ListApplicationMonitorDetectResultRequest,
    ListApplicationMonitorDetectResultResponseBody,
    ListApplicationMonitorDetectResultResponse,
    ListAvailableAccelerateAreasRequest,
    ListAvailableAccelerateAreasResponseBody,
    ListAvailableAccelerateAreasResponse,
    ListAvailableBusiRegionsRequest,
    ListAvailableBusiRegionsResponseBody,
    ListAvailableBusiRegionsResponse,
    ListBandwidthPackagesRequest,
    ListBandwidthPackagesResponseBody,
    ListBandwidthPackagesResponse,
    ListBandwidthackagesRequest,
    ListBandwidthackagesResponseBody,
    ListBandwidthackagesResponse,
    ListBasicAccelerateIpEndpointRelationsRequest,
    ListBasicAccelerateIpEndpointRelationsResponseBody,
    ListBasicAccelerateIpEndpointRelationsResponse,
    ListBasicAccelerateIpsRequest,
    ListBasicAccelerateIpsResponseBody,
    ListBasicAccelerateIpsResponse,
    ListBasicAcceleratorsRequest,
    ListBasicAcceleratorsResponseBody,
    ListBasicAcceleratorsResponse,
    ListBasicEndpointsRequest,
    ListBasicEndpointsResponseBody,
    ListBasicEndpointsResponse,
    ListBusiRegionsRequest,
    ListBusiRegionsResponseBody,
    ListBusiRegionsResponse,
    ListCommonAreasRequest,
    ListCommonAreasResponseBody,
    ListCommonAreasResponse,
    ListCustomRoutingEndpointGroupDestinationsRequest,
    ListCustomRoutingEndpointGroupDestinationsResponseBody,
    ListCustomRoutingEndpointGroupDestinationsResponse,
    ListCustomRoutingEndpointGroupsRequest,
    ListCustomRoutingEndpointGroupsResponseBody,
    ListCustomRoutingEndpointGroupsResponse,
    ListCustomRoutingEndpointTrafficPoliciesRequest,
    ListCustomRoutingEndpointTrafficPoliciesResponseBody,
    ListCustomRoutingEndpointTrafficPoliciesResponse,
    ListCustomRoutingEndpointsRequest,
    ListCustomRoutingEndpointsResponseBody,
    ListCustomRoutingEndpointsResponse,
    ListCustomRoutingPortMappingsRequest,
    ListCustomRoutingPortMappingsResponseBody,
    ListCustomRoutingPortMappingsResponse,
    ListCustomRoutingPortMappingsByDestinationRequest,
    ListCustomRoutingPortMappingsByDestinationResponseBody,
    ListCustomRoutingPortMappingsByDestinationResponse,
    ListDomainsRequest,
    ListDomainsResponseBody,
    ListDomainsResponse,
    ListEndpointGroupIpAddressCidrBlocksRequest,
    ListEndpointGroupIpAddressCidrBlocksResponseBody,
    ListEndpointGroupIpAddressCidrBlocksResponse,
    ListEndpointGroupsRequest,
    ListEndpointGroupsResponseBody,
    ListEndpointGroupsResponse,
    ListForwardingRulesRequest,
    ListForwardingRulesResponseBody,
    ListForwardingRulesResponse,
    ListIpSetsRequest,
    ListIpSetsResponseBody,
    ListIpSetsResponse,
    ListIspTypesRequest,
    ListIspTypesResponseBody,
    ListIspTypesResponse,
    ListListenerCertificatesRequest,
    ListListenerCertificatesResponseBody,
    ListListenerCertificatesResponse,
    ListListenersRequest,
    ListListenersResponseBody,
    ListListenersResponse,
    ListSpareIpsRequest,
    ListSpareIpsResponseBody,
    ListSpareIpsResponse,
    ListSystemSecurityPoliciesRequest,
    ListSystemSecurityPoliciesResponseBody,
    ListSystemSecurityPoliciesResponse,
    ListTagResourcesRequest,
    ListTagResourcesResponseBody,
    ListTagResourcesResponse,
    OpenAcceleratorServiceRequest,
    OpenAcceleratorServiceResponseBody,
    OpenAcceleratorServiceResponse,
    QueryCrossBorderApprovalStatusRequest,
    QueryCrossBorderApprovalStatusResponseBody,
    QueryCrossBorderApprovalStatusResponse,
    RemoveEntriesFromAclRequest,
    RemoveEntriesFromAclResponseBody,
    RemoveEntriesFromAclResponse,
    ReplaceBandwidthPackageRequest,
    ReplaceBandwidthPackageResponseBody,
    ReplaceBandwidthPackageResponse,
    TagResourcesRequest,
    TagResourcesResponseBody,
    TagResourcesResponse,
    UntagResourcesRequest,
    UntagResourcesResponseBody,
    UntagResourcesResponse,
    UpdateAcceleratorRequest,
    UpdateAcceleratorResponseBody,
    UpdateAcceleratorResponse,
    UpdateAcceleratorAutoRenewAttributeRequest,
    UpdateAcceleratorAutoRenewAttributeResponseBody,
    UpdateAcceleratorAutoRenewAttributeResponse,
    UpdateAcceleratorConfirmRequest,
    UpdateAcceleratorConfirmResponseBody,
    UpdateAcceleratorConfirmResponse,
    UpdateAcceleratorCrossBorderModeRequest,
    UpdateAcceleratorCrossBorderModeResponseBody,
    UpdateAcceleratorCrossBorderModeResponse,
    UpdateAcceleratorCrossBorderStatusRequest,
    UpdateAcceleratorCrossBorderStatusResponseBody,
    UpdateAcceleratorCrossBorderStatusResponse,
    UpdateAclAttributeRequest,
    UpdateAclAttributeResponseBody,
    UpdateAclAttributeResponse,
    UpdateAdditionalCertificateWithListenerRequest,
    UpdateAdditionalCertificateWithListenerResponseBody,
    UpdateAdditionalCertificateWithListenerResponse,
    UpdateApplicationMonitorRequest,
    UpdateApplicationMonitorResponseBody,
    UpdateApplicationMonitorResponse,
    UpdateBandwidthPackagaAutoRenewAttributeRequest,
    UpdateBandwidthPackagaAutoRenewAttributeResponseBody,
    UpdateBandwidthPackagaAutoRenewAttributeResponse,
    UpdateBandwidthPackageRequest,
    UpdateBandwidthPackageResponseBody,
    UpdateBandwidthPackageResponse,
    UpdateBasicAcceleratorRequest,
    UpdateBasicAcceleratorResponseBody,
    UpdateBasicAcceleratorResponse,
    UpdateBasicEndpointRequest,
    UpdateBasicEndpointResponseBody,
    UpdateBasicEndpointResponse,
    UpdateBasicEndpointGroupRequest,
    UpdateBasicEndpointGroupResponseBody,
    UpdateBasicEndpointGroupResponse,
    UpdateBasicIpSetRequest,
    UpdateBasicIpSetResponseBody,
    UpdateBasicIpSetResponse,
    UpdateCustomRoutingEndpointGroupAttributeRequest,
    UpdateCustomRoutingEndpointGroupAttributeResponseBody,
    UpdateCustomRoutingEndpointGroupAttributeResponse,
    UpdateCustomRoutingEndpointGroupDestinationsRequest,
    UpdateCustomRoutingEndpointGroupDestinationsResponseBody,
    UpdateCustomRoutingEndpointGroupDestinationsResponse,
    UpdateCustomRoutingEndpointTrafficPoliciesRequest,
    UpdateCustomRoutingEndpointTrafficPoliciesResponseBody,
    UpdateCustomRoutingEndpointTrafficPoliciesResponse,
    UpdateCustomRoutingEndpointsRequest,
    UpdateCustomRoutingEndpointsResponseBody,
    UpdateCustomRoutingEndpointsResponse,
    UpdateDomainRequest,
    UpdateDomainResponseBody,
    UpdateDomainResponse,
    UpdateDomainStateRequest,
    UpdateDomainStateResponseBody,
    UpdateDomainStateResponse,
    UpdateEndpointGroupRequest,
    UpdateEndpointGroupResponseBody,
    UpdateEndpointGroupResponse,
    UpdateEndpointGroupAttributeRequest,
    UpdateEndpointGroupAttributeResponseBody,
    UpdateEndpointGroupAttributeResponse,
    UpdateEndpointGroupsRequest,
    UpdateEndpointGroupsResponseBody,
    UpdateEndpointGroupsResponse,
    UpdateForwardingRulesRequest,
    UpdateForwardingRulesResponseBody,
    UpdateForwardingRulesResponse,
    UpdateIpSetRequest,
    UpdateIpSetResponseBody,
    UpdateIpSetResponse,
    UpdateIpSetsRequest,
    UpdateIpSetsResponseBody,
    UpdateIpSetsResponse,
    UpdateListenerRequest,
    UpdateListenerResponseBody,
    UpdateListenerResponse,
    UpdateLogStoreConfigRequest,
    UpdateLogStoreConfigResponseBody,
    UpdateLogStoreConfigResponse,
    UpdateServiceManagedControlRequest,
    UpdateServiceManagedControlResponseBody,
    UpdateServiceManagedControlResponse,
    AddEntriesToAclRequestAclEntries,
    AssociateAdditionalCertificatesWithListenerRequestCertificates,
    AttachDdosToAcceleratorRequestDdosConfigList,
    CreateAcceleratorRequestIpSetConfig,
    CreateAcceleratorRequestTag,
    CreateAclRequestAclEntries,
    CreateAclRequestTag,
    CreateBandwidthPackageRequestTag,
    CreateBasicAccelerateIpEndpointRelationsRequestAccelerateIpEndpointRelations,
    CreateBasicAcceleratorRequestTag,
    CreateBasicEndpointsRequestEndpoints,
    CreateBasicEndpointsResponseBodyEndpoints,
    CreateCustomRoutingEndpointGroupDestinationsRequestDestinationConfigurations,
    CreateCustomRoutingEndpointGroupsRequestEndpointGroupConfigurationsDestinationConfigurations,
    CreateCustomRoutingEndpointGroupsRequestEndpointGroupConfigurationsEndpointConfigurationsPolicyConfigurationsPortRanges,
    CreateCustomRoutingEndpointGroupsRequestEndpointGroupConfigurationsEndpointConfigurationsPolicyConfigurations,
    CreateCustomRoutingEndpointGroupsRequestEndpointGroupConfigurationsEndpointConfigurations,
    CreateCustomRoutingEndpointGroupsRequestEndpointGroupConfigurations,
    CreateCustomRoutingEndpointTrafficPoliciesRequestPolicyConfigurationsPortRanges,
    CreateCustomRoutingEndpointTrafficPoliciesRequestPolicyConfigurations,
    CreateCustomRoutingEndpointsRequestEndpointConfigurationsPolicyConfigurationsPortRanges,
    CreateCustomRoutingEndpointsRequestEndpointConfigurationsPolicyConfigurations,
    CreateCustomRoutingEndpointsRequestEndpointConfigurations,
    CreateEndpointGroupRequestEndpointConfigurations,
    CreateEndpointGroupRequestPortOverrides,
    CreateEndpointGroupRequestTag,
    CreateEndpointGroupsRequestEndpointGroupConfigurationsEndpointConfigurations,
    CreateEndpointGroupsRequestEndpointGroupConfigurationsPortOverrides,
    CreateEndpointGroupsRequestEndpointGroupConfigurationsSystemTag,
    CreateEndpointGroupsRequestEndpointGroupConfigurationsTag,
    CreateEndpointGroupsRequestEndpointGroupConfigurations,
    CreateForwardingRulesRequestForwardingRulesRuleActionsForwardGroupConfigServerGroupTuples,
    CreateForwardingRulesRequestForwardingRulesRuleActionsForwardGroupConfig,
    CreateForwardingRulesRequestForwardingRulesRuleActions,
    CreateForwardingRulesRequestForwardingRulesRuleConditionsHostConfig,
    CreateForwardingRulesRequestForwardingRulesRuleConditionsPathConfig,
    CreateForwardingRulesRequestForwardingRulesRuleConditions,
    CreateForwardingRulesRequestForwardingRules,
    CreateForwardingRulesResponseBodyForwardingRules,
    CreateIpSetsRequestAccelerateRegion,
    CreateIpSetsResponseBodyIpSets,
    CreateListenerRequestCertificates,
    CreateListenerRequestCustomRoutingEndpointGroupConfigurationsDestinationConfigurations,
    CreateListenerRequestCustomRoutingEndpointGroupConfigurationsEndpointConfigurationsPolicyConfigurationsPortRanges,
    CreateListenerRequestCustomRoutingEndpointGroupConfigurationsEndpointConfigurationsPolicyConfigurations,
    CreateListenerRequestCustomRoutingEndpointGroupConfigurationsEndpointConfigurations,
    CreateListenerRequestCustomRoutingEndpointGroupConfigurations,
    CreateListenerRequestEndpointGroupConfigurationsEndpointConfigurations,
    CreateListenerRequestEndpointGroupConfigurationsPortOverrides,
    CreateListenerRequestEndpointGroupConfigurations,
    CreateListenerRequestPortRanges,
    CreateListenerRequestXForwardedForConfig,
    DeleteForwardingRulesResponseBodyForwardingRules,
    DescribeAcceleratorResponseBodyBasicBandwidthPackage,
    DescribeAcceleratorResponseBodyCrossDomainBandwidthPackage,
    DescribeAcceleratorResponseBodyDdosConfigList,
    DescribeAcceleratorResponseBodyIpSetConfig,
    DescribeAcceleratorResponseBodyServiceManagedInfos,
    DescribeAcceleratorResponseBodyTags,
    DescribeApplicationMonitorResponseBodyIspCityList,
    DescribeBandwidthPackageResponseBodyTags,
    DescribeCommodityResponseBodyComponentsPropertiesPropertyValueList,
    DescribeCommodityResponseBodyComponentsProperties,
    DescribeCommodityResponseBodyComponents,
    DescribeCommodityPriceRequestOrdersComponentsProperties,
    DescribeCommodityPriceRequestOrdersComponents,
    DescribeCommodityPriceRequestOrders,
    DescribeCommodityPriceResponseBodyOrderDetailsModuleDetails,
    DescribeCommodityPriceResponseBodyOrderDetailsPromDetails,
    DescribeCommodityPriceResponseBodyOrderDetails,
    DescribeCommodityPriceResponseBodyPromotions,
    DescribeCommodityPriceResponseBodyRuleDetails,
    DescribeCustomRoutingEndPointTrafficPolicyResponseBodyPortRanges,
    DescribeCustomRoutingEndPointTrafficPolicyResponseBodyServiceManagedInfos,
    DescribeCustomRoutingEndpointResponseBodyServiceManagedInfos,
    DescribeCustomRoutingEndpointGroupResponseBodyServiceManagedInfos,
    DescribeCustomRoutingEndpointGroupDestinationsResponseBodyServiceManagedInfos,
    DescribeEndpointGroupResponseBodyEndpointConfigurations,
    DescribeEndpointGroupResponseBodyEndpointPrivateIpList,
    DescribeEndpointGroupResponseBodyPortOverrides,
    DescribeEndpointGroupResponseBodyServiceManagedInfos,
    DescribeEndpointGroupResponseBodyTags,
    DescribeIpSetResponseBodyServiceManagedInfos,
    DescribeListenerResponseBodyBackendPorts,
    DescribeListenerResponseBodyCertificates,
    DescribeListenerResponseBodyPortRanges,
    DescribeListenerResponseBodyRelatedAcls,
    DescribeListenerResponseBodyServiceManagedInfos,
    DescribeListenerResponseBodyXForwardedForConfig,
    DescribeRegionsResponseBodyRegions,
    DetachDdosFromAcceleratorRequestDdosConfigList,
    GetAclResponseBodyAclEntries,
    GetAclResponseBodyRelatedListeners,
    GetAclResponseBodyTags,
    GetBasicAcceleratorResponseBodyBasicBandwidthPackage,
    GetBasicAcceleratorResponseBodyCrossDomainBandwidthPackage,
    GetBasicAcceleratorResponseBodyTags,
    GetGlobalAcceleratorResourcesResponseBodyAssociatedResources,
    GetHealthStatusResponseBodyEndpointGroupsEndpoints,
    GetHealthStatusResponseBodyEndpointGroups,
    ListAccelerateAreasResponseBodyAreasRegionList,
    ListAccelerateAreasResponseBodyAreas,
    ListAcceleratorsRequestTag,
    ListAcceleratorsResponseBodyAcceleratorsBasicBandwidthPackage,
    ListAcceleratorsResponseBodyAcceleratorsCrossDomainBandwidthPackage,
    ListAcceleratorsResponseBodyAcceleratorsDdosConfigList,
    ListAcceleratorsResponseBodyAcceleratorsIpSetConfig,
    ListAcceleratorsResponseBodyAcceleratorsServiceManagedInfos,
    ListAcceleratorsResponseBodyAcceleratorsTags,
    ListAcceleratorsResponseBodyAccelerators,
    ListAclsRequestTag,
    ListAclsResponseBodyAclsTags,
    ListAclsResponseBodyAcls,
    ListApplicationMonitorResponseBodyApplicationMonitors,
    ListApplicationMonitorDetectResultResponseBodyApplicationMonitorDetectResultList,
    ListAvailableAccelerateAreasResponseBodyAreasRegionList,
    ListAvailableAccelerateAreasResponseBodyAreas,
    ListAvailableBusiRegionsResponseBodyRegions,
    ListBandwidthPackagesRequestTag,
    ListBandwidthPackagesResponseBodyBandwidthPackagesTags,
    ListBandwidthPackagesResponseBodyBandwidthPackages,
    ListBandwidthackagesResponseBodyBandwidthPackagesTags,
    ListBandwidthackagesResponseBodyBandwidthPackages,
    ListBasicAccelerateIpEndpointRelationsResponseBodyAccelerateIpEndpointRelations,
    ListBasicAccelerateIpsResponseBodyAccelerateIps,
    ListBasicAcceleratorsRequestTag,
    ListBasicAcceleratorsResponseBodyAcceleratorsBasicBandwidthPackage,
    ListBasicAcceleratorsResponseBodyAcceleratorsCrossDomainBandwidthPackage,
    ListBasicAcceleratorsResponseBodyAcceleratorsTags,
    ListBasicAcceleratorsResponseBodyAccelerators,
    ListBasicEndpointsResponseBodyEndpoints,
    ListBusiRegionsResponseBodyRegions,
    ListCommonAreasResponseBodyAreasRegionList,
    ListCommonAreasResponseBodyAreas,
    ListCustomRoutingEndpointGroupDestinationsResponseBodyDestinationsServiceManagedInfos,
    ListCustomRoutingEndpointGroupDestinationsResponseBodyDestinations,
    ListCustomRoutingEndpointGroupsResponseBodyEndpointGroupsServiceManagedInfos,
    ListCustomRoutingEndpointGroupsResponseBodyEndpointGroups,
    ListCustomRoutingEndpointTrafficPoliciesResponseBodyPoliciesPortRanges,
    ListCustomRoutingEndpointTrafficPoliciesResponseBodyPoliciesServiceManagedInfos,
    ListCustomRoutingEndpointTrafficPoliciesResponseBodyPolicies,
    ListCustomRoutingEndpointsResponseBodyEndpointsServiceManagedInfos,
    ListCustomRoutingEndpointsResponseBodyEndpoints,
    ListCustomRoutingPortMappingsResponseBodyPortMappingsDestinationSocketAddress,
    ListCustomRoutingPortMappingsResponseBodyPortMappings,
    ListCustomRoutingPortMappingsByDestinationResponseBodyPortMappingsDestinationSocketAddress,
    ListCustomRoutingPortMappingsByDestinationResponseBodyPortMappings,
    ListDomainsResponseBodyDomainsAcceleratorsServiceManagedInfos,
    ListDomainsResponseBodyDomainsAccelerators,
    ListDomainsResponseBodyDomains,
    ListEndpointGroupsRequestTag,
    ListEndpointGroupsResponseBodyEndpointGroupsEndpointConfigurations,
    ListEndpointGroupsResponseBodyEndpointGroupsEndpointPrivateIpList,
    ListEndpointGroupsResponseBodyEndpointGroupsPortOverrides,
    ListEndpointGroupsResponseBodyEndpointGroupsServiceManagedInfos,
    ListEndpointGroupsResponseBodyEndpointGroupsTags,
    ListEndpointGroupsResponseBodyEndpointGroups,
    ListForwardingRulesResponseBodyForwardingRulesRuleActionsForwardGroupConfigServerGroupTuples,
    ListForwardingRulesResponseBodyForwardingRulesRuleActionsForwardGroupConfig,
    ListForwardingRulesResponseBodyForwardingRulesRuleActions,
    ListForwardingRulesResponseBodyForwardingRulesRuleConditionsHostConfig,
    ListForwardingRulesResponseBodyForwardingRulesRuleConditionsPathConfig,
    ListForwardingRulesResponseBodyForwardingRulesRuleConditions,
    ListForwardingRulesResponseBodyForwardingRulesServiceManagedInfos,
    ListForwardingRulesResponseBodyForwardingRules,
    ListIpSetsResponseBodyIpSetsServiceManagedInfos,
    ListIpSetsResponseBodyIpSets,
    ListListenerCertificatesResponseBodyCertificates,
    ListListenersResponseBodyListenersBackendPorts,
    ListListenersResponseBodyListenersCertificates,
    ListListenersResponseBodyListenersPortRanges,
    ListListenersResponseBodyListenersServiceManagedInfos,
    ListListenersResponseBodyListenersXForwardedForConfig,
    ListListenersResponseBodyListeners,
    ListSpareIpsResponseBodySpareIps,
    ListSystemSecurityPoliciesResponseBodySecurityPolicies,
    ListTagResourcesRequestTag,
    ListTagResourcesResponseBodyTagResourcesTagResource,
    ListTagResourcesResponseBodyTagResources,
    RemoveEntriesFromAclRequestAclEntries,
    TagResourcesRequestTag,
    UpdateCustomRoutingEndpointGroupDestinationsRequestDestinationConfigurations,
    UpdateCustomRoutingEndpointTrafficPoliciesRequestPolicyConfigurationsPortRanges,
    UpdateCustomRoutingEndpointTrafficPoliciesRequestPolicyConfigurations,
    UpdateCustomRoutingEndpointsRequestEndpointConfigurationsPolicyConfigurationsPortRanges,
    UpdateCustomRoutingEndpointsRequestEndpointConfigurationsPolicyConfigurations,
    UpdateCustomRoutingEndpointsRequestEndpointConfigurations,
    UpdateEndpointGroupRequestEndpointConfigurations,
    UpdateEndpointGroupRequestPortOverrides,
    UpdateEndpointGroupsRequestEndpointGroupConfigurationsEndpointConfigurations,
    UpdateEndpointGroupsRequestEndpointGroupConfigurationsPortOverrides,
    UpdateEndpointGroupsRequestEndpointGroupConfigurations,
    UpdateForwardingRulesRequestForwardingRulesRuleActionsForwardGroupConfigServerGroupTuples,
    UpdateForwardingRulesRequestForwardingRulesRuleActionsForwardGroupConfig,
    UpdateForwardingRulesRequestForwardingRulesRuleActions,
    UpdateForwardingRulesRequestForwardingRulesRuleConditionsHostConfig,
    UpdateForwardingRulesRequestForwardingRulesRuleConditionsPathConfig,
    UpdateForwardingRulesRequestForwardingRulesRuleConditions,
    UpdateForwardingRulesRequestForwardingRules,
    UpdateForwardingRulesResponseBodyForwardingRules,
    UpdateIpSetsRequestIpSets,
    UpdateListenerRequestBackendPorts,
    UpdateListenerRequestCertificates,
    UpdateListenerRequestPortRanges,
    UpdateListenerRequestXForwardedForConfig
]



# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListCommonAreasRequest(DaraModel):
    def __init__(
        self,
        ip_version: str = None,
        is_epg: bool = None,
        is_ip_set: bool = None,
    ):
        # The IP version used to connect to the GA instance. Valid values:
        # 
        # *   **IPv4** (default)
        # *   **IPv6**
        self.ip_version = ip_version
        # Specifies whether to query regions where endpoint groups of GA can be deployed. Valid values:
        # 
        # *   **true**: yes
        # *   **false** (default): no
        self.is_epg = is_epg
        # Specifies whether to query regions supported by GA. Valid values:
        # 
        # *   **true**
        # *   **false** (default)
        self.is_ip_set = is_ip_set

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.ip_version is not None:
            result['IpVersion'] = self.ip_version

        if self.is_epg is not None:
            result['IsEpg'] = self.is_epg

        if self.is_ip_set is not None:
            result['IsIpSet'] = self.is_ip_set

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('IpVersion') is not None:
            self.ip_version = m.get('IpVersion')

        if m.get('IsEpg') is not None:
            self.is_epg = m.get('IsEpg')

        if m.get('IsIpSet') is not None:
            self.is_ip_set = m.get('IsIpSet')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetSpareIpRequest(DaraModel):
    def __init__(
        self,
        accelerator_id: str = None,
        client_token: str = None,
        dry_run: bool = None,
        region_id: str = None,
        spare_ip: str = None,
    ):
        # The GA instance ID.
        # 
        # This parameter is required.
        self.accelerator_id = accelerator_id
        # The client token that is used to ensure the idempotence of the request.
        # 
        # You can use the client to generate the token, but you must make sure that the token is unique among different requests. The token can contain only ASCII characters.
        self.client_token = client_token
        # Specifies whether to perform only a dry run, without performing the actual request.
        # 
        # *   **true**: performs only a dry run. The system checks the request for potential issues, including missing parameter values, incorrect request syntax, and service limits. If the request fails the dry run, an error message is returned. If the request passes the dry run, the `DryRunOperation` error code is returned.
        # *   **false** (default): performs a dry run and performs the actual request. If the request passes the dry run, a 2xx HTTP status code is returned and the operation is performed.
        self.dry_run = dry_run
        # The region ID of the GA instance. Set the value to **cn-hangzhou**.
        # 
        # This parameter is required.
        self.region_id = region_id
        # The secondary IP address that is associated with the CNAME. If the acceleration area becomes unavailable, GA redirects traffic to the secondary IP address.
        # 
        # This parameter is required.
        self.spare_ip = spare_ip

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.accelerator_id is not None:
            result['AcceleratorId'] = self.accelerator_id

        if self.client_token is not None:
            result['ClientToken'] = self.client_token

        if self.dry_run is not None:
            result['DryRun'] = self.dry_run

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        if self.spare_ip is not None:
            result['SpareIp'] = self.spare_ip

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AcceleratorId') is not None:
            self.accelerator_id = m.get('AcceleratorId')

        if m.get('ClientToken') is not None:
            self.client_token = m.get('ClientToken')

        if m.get('DryRun') is not None:
            self.dry_run = m.get('DryRun')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        if m.get('SpareIp') is not None:
            self.spare_ip = m.get('SpareIp')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_ga20191120 import models as main_models
from darabonba.model import DaraModel

class UpdateCustomRoutingEndpointTrafficPoliciesRequest(DaraModel):
    def __init__(
        self,
        client_token: str = None,
        endpoint_id: str = None,
        policy_configurations: List[main_models.UpdateCustomRoutingEndpointTrafficPoliciesRequestPolicyConfigurations] = None,
        region_id: str = None,
    ):
        # The client token that is used to ensure the idempotence of the request.
        # 
        # You can use the client to generate the token, but you must make sure that the token is unique among different requests. The token can contain only ASCII characters.
        # 
        # >  If you do not specify this parameter, the system automatically uses the **request ID** as the **client token**. The **request ID** may be different for each request.
        self.client_token = client_token
        # The ID of the endpoint for which you want to modify the traffic policies.
        # 
        # This parameter is required.
        self.endpoint_id = endpoint_id
        # The access policies.
        # 
        # You can specify a maximum of 500 traffic policies for each endpoint.
        # 
        # This parameter is required.
        self.policy_configurations = policy_configurations
        # The region ID of the Global Accelerator (GA) instance. Set the value to **cn-hangzhou**.
        # 
        # This parameter is required.
        self.region_id = region_id

    def validate(self):
        if self.policy_configurations:
            for v1 in self.policy_configurations:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.client_token is not None:
            result['ClientToken'] = self.client_token

        if self.endpoint_id is not None:
            result['EndpointId'] = self.endpoint_id

        result['PolicyConfigurations'] = []
        if self.policy_configurations is not None:
            for k1 in self.policy_configurations:
                result['PolicyConfigurations'].append(k1.to_map() if k1 else None)

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ClientToken') is not None:
            self.client_token = m.get('ClientToken')

        if m.get('EndpointId') is not None:
            self.endpoint_id = m.get('EndpointId')

        self.policy_configurations = []
        if m.get('PolicyConfigurations') is not None:
            for k1 in m.get('PolicyConfigurations'):
                temp_model = main_models.UpdateCustomRoutingEndpointTrafficPoliciesRequestPolicyConfigurations()
                self.policy_configurations.append(temp_model.from_map(k1))

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        return self

class UpdateCustomRoutingEndpointTrafficPoliciesRequestPolicyConfigurations(DaraModel):
    def __init__(
        self,
        address: str = None,
        policy_id: str = None,
        port_ranges: List[main_models.UpdateCustomRoutingEndpointTrafficPoliciesRequestPolicyConfigurationsPortRanges] = None,
    ):
        # The IP address of the destination which to allow traffic.
        # 
        # This parameter takes effect only when you set the **TrafficToEndpointPolicy** parameter to **AllowCustom**. You can call the [DescribeCustomRoutingEndpoint](https://help.aliyun.com/document_detail/449386.html) operation to query the traffic policy of an endpoint.
        # 
        # You can specify a maximum of 500 traffic policies for each endpoint.
        # 
        # >  This parameter is required.
        self.address = address
        # The ID of the traffic policy that you want to modify.
        # 
        # >  This parameter is required.
        self.policy_id = policy_id
        # The port range of the destination to which traffic is forwarded. The value of this parameter must fall within the port range of the endpoint group.
        # 
        # If you do not specify object, traffic is forwarded to all ports.
        # 
        # This parameter takes effect only when you set the **TrafficToEndpointPolicy** parameter to **AllowCustom**. You can call the [DescribeCustomRoutingEndpoint](https://help.aliyun.com/document_detail/449386.html) operation to query the traffic policy of an endpoint.
        # 
        # You can specify a maximum of 500 port ranges for each endpoint and a maximum of 10 port ranges for each traffic policy.
        self.port_ranges = port_ranges

    def validate(self):
        if self.port_ranges:
            for v1 in self.port_ranges:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.address is not None:
            result['Address'] = self.address

        if self.policy_id is not None:
            result['PolicyId'] = self.policy_id

        result['PortRanges'] = []
        if self.port_ranges is not None:
            for k1 in self.port_ranges:
                result['PortRanges'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Address') is not None:
            self.address = m.get('Address')

        if m.get('PolicyId') is not None:
            self.policy_id = m.get('PolicyId')

        self.port_ranges = []
        if m.get('PortRanges') is not None:
            for k1 in m.get('PortRanges'):
                temp_model = main_models.UpdateCustomRoutingEndpointTrafficPoliciesRequestPolicyConfigurationsPortRanges()
                self.port_ranges.append(temp_model.from_map(k1))

        return self

class UpdateCustomRoutingEndpointTrafficPoliciesRequestPolicyConfigurationsPortRanges(DaraModel):
    def __init__(
        self,
        from_port: int = None,
        to_port: int = None,
    ):
        # The first port of the destination port range. The value of this parameter must fall within the port range of the backend service.
        # 
        # This parameter takes effect only when you set the **TrafficToEndpointPolicy** parameter to **AllowCustom**. You can call the [DescribeCustomRoutingEndpoint](https://help.aliyun.com/document_detail/449386.html) operation to query the traffic policy of an endpoint.
        # 
        # If the start port and end port values are empty, traffic on all ports of the destination is allowed.
        # 
        # You can specify a maximum of 500 port ranges for each endpoint and a maximum of 10 port ranges for each traffic policy.
        self.from_port = from_port
        # The last port of the destination port range. The value of this parameter must fall within the port range of the backend service.
        # 
        # This parameter takes effect only when you set the **TrafficToEndpointPolicy** parameter to **AllowCustom**. You can call the [DescribeCustomRoutingEndpoint](https://help.aliyun.com/document_detail/449386.html) operation to query the traffic policy of an endpoint.
        # 
        # If the start port and end port values are empty, traffic on all ports of the destination is allowed.
        # 
        # You can specify a maximum of 500 port ranges for each endpoint and a maximum of 10 port ranges for each traffic policy.
        self.to_port = to_port

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.from_port is not None:
            result['FromPort'] = self.from_port

        if self.to_port is not None:
            result['ToPort'] = self.to_port

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('FromPort') is not None:
            self.from_port = m.get('FromPort')

        if m.get('ToPort') is not None:
            self.to_port = m.get('ToPort')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_ga20191120 import models as main_models
from darabonba.model import DaraModel

class ListSystemSecurityPoliciesResponseBody(DaraModel):
    def __init__(
        self,
        page_number: int = None,
        page_size: int = None,
        request_id: str = None,
        security_policies: List[main_models.ListSystemSecurityPoliciesResponseBodySecurityPolicies] = None,
        total_count: int = None,
    ):
        # The page number.
        self.page_number = page_number
        # The number of entries per page.
        self.page_size = page_size
        # The request ID.
        self.request_id = request_id
        # The list of TLS security policies.
        self.security_policies = security_policies
        # The total number of entries returned.
        self.total_count = total_count

    def validate(self):
        if self.security_policies:
            for v1 in self.security_policies:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.page_number is not None:
            result['PageNumber'] = self.page_number

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        result['SecurityPolicies'] = []
        if self.security_policies is not None:
            for k1 in self.security_policies:
                result['SecurityPolicies'].append(k1.to_map() if k1 else None)

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('PageNumber') is not None:
            self.page_number = m.get('PageNumber')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        self.security_policies = []
        if m.get('SecurityPolicies') is not None:
            for k1 in m.get('SecurityPolicies'):
                temp_model = main_models.ListSystemSecurityPoliciesResponseBodySecurityPolicies()
                self.security_policies.append(temp_model.from_map(k1))

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        return self

class ListSystemSecurityPoliciesResponseBodySecurityPolicies(DaraModel):
    def __init__(
        self,
        ciphers: List[str] = None,
        security_policy_id: str = None,
        tls_versions: List[str] = None,
    ):
        # The supported cipher suites. The value of this parameter is determined by the value of **TLSVersions**.
        # 
        # The specified cipher suites must be supported by at least one value of **TLSVersions**. For example, if you set TLSVersions to **TLSv1.3**, you must specify cipher suites that are supported by **TLSv1.3**.
        # 
        # *   Valid values when TLSVersions is set to **TLSv1.0** or **TLSv1.1**:
        # 
        #     *   ECDHE-ECDSA-AES128-SHA
        #     *   ECDHE-ECDSA-AES256-SHA
        #     *   ECDHE-RSA-AES128-SHA
        #     *   ECDHE-RSA-AES256-SHA
        #     *   AES128-SHA
        #     *   AES256-SHA
        #     *   DES-CBC3-SHA
        # 
        # *   Valid values when TLSVersions is set to **TLSv1.2**:
        # 
        #     *   ECDHE-ECDSA-AES128-SHA
        #     *   ECDHE-ECDSA-AES256-SHA
        #     *   ECDHE-RSA-AES128-SHA
        #     *   ECDHE-RSA-AES256-SHA
        #     *   AES128-SHA
        #     *   AES256-SHA
        #     *   DES-CBC3-SHA
        #     *   ECDHE-ECDSA-AES128-GCM-SHA256
        #     *   ECDHE-ECDSA-AES256-GCM-SHA384
        #     *   ECDHE-ECDSA-AES128-SHA256
        #     *   ECDHE-ECDSA-AES256-SHA384
        #     *   ECDHE-RSA-AES128-GCM-SHA256
        #     *   ECDHE-RSA-AES256-GCM-SHA384
        #     *   ECDHE-RSA-AES128-SHA256
        #     *   ECDHE-RSA-AES256-SHA384
        #     *   AES128-GCM-SHA256
        #     *   AES256-GCM-SHA384
        #     *   AES128-SHA256
        #     *   AES256-SHA256
        # 
        # *   Valid values when TLSVersions is set to **TLSv1.3**:
        # 
        #     *   TLS_AES_128_GCM_SHA256
        #     *   TLS_AES_256_GCM_SHA384
        #     *   TLS_CHACHA20_POLY1305_SHA256
        #     *   TLS_AES_128_CCM_SHA256
        #     *   TLS_AES_128_CCM_8_SHA256
        self.ciphers = ciphers
        # The ID of the TLS security policy.
        self.security_policy_id = security_policy_id
        # The supported TLS versions. Valid values: **TLSv1.0**, **TLSv1.1**, **TLSv1.2**, and **TLSv1.3**.
        self.tls_versions = tls_versions

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.ciphers is not None:
            result['Ciphers'] = self.ciphers

        if self.security_policy_id is not None:
            result['SecurityPolicyId'] = self.security_policy_id

        if self.tls_versions is not None:
            result['TlsVersions'] = self.tls_versions

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Ciphers') is not None:
            self.ciphers = m.get('Ciphers')

        if m.get('SecurityPolicyId') is not None:
            self.security_policy_id = m.get('SecurityPolicyId')

        if m.get('TlsVersions') is not None:
            self.tls_versions = m.get('TlsVersions')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class CreateCustomRoutingEndpointGroupDestinationsResponseBody(DaraModel):
    def __init__(
        self,
        destination_ids: List[str] = None,
        request_id: str = None,
    ):
        # The IDs of the endpoint group mappings.
        self.destination_ids = destination_ids
        # The IDs of the endpoint group mappings.
        self.request_id = request_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.destination_ids is not None:
            result['DestinationIds'] = self.destination_ids

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DestinationIds') is not None:
            self.destination_ids = m.get('DestinationIds')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class ListIspTypesResponseBody(DaraModel):
    def __init__(
        self,
        isp_type_list: List[str] = None,
        request_id: str = None,
    ):
        # The line types of EIPs in the acceleration region.
        # 
        # *   **BGP** (default): BGP (Multi-ISP) lines
        # *   **BGP_PRO**: BGP (Multi-ISP) Pro lines
        # 
        # If you have the permissions to use single-ISP bandwidth, one of the following values may be returned:
        # 
        # *   **ChinaTelecom**: China Telecom (single ISP)
        # *   **ChinaUnicom**: China Unicom (single ISP)
        # *   **ChinaMobile**: China Mobile (single ISP)
        # *   **ChinaTelecom_L2**: China Telecom_L2 (single ISP)
        # *   **ChinaUnicom_L2**: China Unicom_L2 (single ISP)
        # *   **ChinaMobile_L2**: China Mobile_L2 (single ISP)
        # 
        # > Different acceleration regions support different single-ISP BGP lines.
        self.isp_type_list = isp_type_list
        # The ID of the request.
        self.request_id = request_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.isp_type_list is not None:
            result['IspTypeList'] = self.isp_type_list

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('IspTypeList') is not None:
            self.isp_type_list = m.get('IspTypeList')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class UpdateBandwidthPackageRequest(DaraModel):
    def __init__(
        self,
        auto_pay: bool = None,
        auto_use_coupon: bool = None,
        bandwidth: int = None,
        bandwidth_package_id: str = None,
        bandwidth_type: str = None,
        description: str = None,
        name: str = None,
        region_id: str = None,
    ):
        # Specifies whether to enable automatic payment. Valid values:
        # 
        # *   **false**: disables automatic payment. This is the default value. If you select this option, you must go to [Order Center](https://usercenter2-intl.aliyun.com/order/list) to complete the payment after an order is generated.
        # *   **true**: enables automatic payment. Payments are automatically completed.
        # 
        # >  This parameter takes effect only if you call the UpdateBandwidthPackage operation to upgrade a bandwidth plan.
        self.auto_pay = auto_pay
        # Specifies whether to use coupons. Valid values:
        # 
        # *   **true**
        # *   **false** (default)
        self.auto_use_coupon = auto_use_coupon
        # The bandwidth value of the bandwidth plan. Unit: Mbit/s.
        # 
        # Valid values: **2** to **2000**.
        self.bandwidth = bandwidth
        # The ID of the bandwidth plan that you want to modify.
        # 
        # This parameter is required.
        self.bandwidth_package_id = bandwidth_package_id
        # The type of bandwidth. Valid values:
        # 
        # *   **Basic**
        # *   **Enhanced**
        # *   **Advanced**
        # 
        # >  You can upgrade **Basic** bandwidth to **Enhanced** bandwidth or downgrade Enhanced bandwidth to Basic bandwidth. You cannot change **Advanced** bandwidth to another type of bandwidth.
        self.bandwidth_type = bandwidth_type
        # The description of the bandwidth plan.
        # 
        # The description can be up to 256 characters in length.
        self.description = description
        # The name of the bandwidth plan. The name must be 2 to 128 characters in length, and can contain letters, digits, periods (.), underscores (_), and hyphens (-). The name must start with a letter.
        self.name = name
        # The region ID of the GA instance. Set the value to **cn-hangzhou**.
        # 
        # This parameter is required.
        self.region_id = region_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auto_pay is not None:
            result['AutoPay'] = self.auto_pay

        if self.auto_use_coupon is not None:
            result['AutoUseCoupon'] = self.auto_use_coupon

        if self.bandwidth is not None:
            result['Bandwidth'] = self.bandwidth

        if self.bandwidth_package_id is not None:
            result['BandwidthPackageId'] = self.bandwidth_package_id

        if self.bandwidth_type is not None:
            result['BandwidthType'] = self.bandwidth_type

        if self.description is not None:
            result['Description'] = self.description

        if self.name is not None:
            result['Name'] = self.name

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AutoPay') is not None:
            self.auto_pay = m.get('AutoPay')

        if m.get('AutoUseCoupon') is not None:
            self.auto_use_coupon = m.get('AutoUseCoupon')

        if m.get('Bandwidth') is not None:
            self.bandwidth = m.get('Bandwidth')

        if m.get('BandwidthPackageId') is not None:
            self.bandwidth_package_id = m.get('BandwidthPackageId')

        if m.get('BandwidthType') is not None:
            self.bandwidth_type = m.get('BandwidthType')

        if m.get('Description') is not None:
            self.description = m.get('Description')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        return self

